# coding: utf-8

# flake8: noqa
"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from infisicalapi_client.models.api_status_get200_response import ApiStatusGet200Response
from infisicalapi_client.models.api_v1_access_approvals_policies_get200_response import ApiV1AccessApprovalsPoliciesGet200Response
from infisicalapi_client.models.api_v1_access_approvals_policies_get200_response_approvals_inner import ApiV1AccessApprovalsPoliciesGet200ResponseApprovalsInner
from infisicalapi_client.models.api_v1_access_approvals_policies_policy_id_patch_request import ApiV1AccessApprovalsPoliciesPolicyIdPatchRequest
from infisicalapi_client.models.api_v1_access_approvals_policies_post_request import ApiV1AccessApprovalsPoliciesPostRequest
from infisicalapi_client.models.api_v1_access_approvals_requests_count_get200_response import ApiV1AccessApprovalsRequestsCountGet200Response
from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response import ApiV1AccessApprovalsRequestsGet200Response
from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response_requests_inner import ApiV1AccessApprovalsRequestsGet200ResponseRequestsInner
from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response_requests_inner_policy import ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerPolicy
from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response_requests_inner_privilege import ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerPrivilege
from infisicalapi_client.models.api_v1_access_approvals_requests_get200_response_requests_inner_reviewers_inner import ApiV1AccessApprovalsRequestsGet200ResponseRequestsInnerReviewersInner
from infisicalapi_client.models.api_v1_access_approvals_requests_post200_response import ApiV1AccessApprovalsRequestsPost200Response
from infisicalapi_client.models.api_v1_access_approvals_requests_post200_response_approval import ApiV1AccessApprovalsRequestsPost200ResponseApproval
from infisicalapi_client.models.api_v1_access_approvals_requests_post_request import ApiV1AccessApprovalsRequestsPostRequest
from infisicalapi_client.models.api_v1_access_approvals_requests_request_id_review_post200_response import ApiV1AccessApprovalsRequestsRequestIdReviewPost200Response
from infisicalapi_client.models.api_v1_access_approvals_requests_request_id_review_post200_response_review import ApiV1AccessApprovalsRequestsRequestIdReviewPost200ResponseReview
from infisicalapi_client.models.api_v1_additional_privilege_identity_delete_request import ApiV1AdditionalPrivilegeIdentityDeleteRequest
from infisicalapi_client.models.api_v1_additional_privilege_identity_get200_response import ApiV1AdditionalPrivilegeIdentityGet200Response
from infisicalapi_client.models.api_v1_additional_privilege_identity_patch_request import ApiV1AdditionalPrivilegeIdentityPatchRequest
from infisicalapi_client.models.api_v1_additional_privilege_identity_patch_request_privilege_details import ApiV1AdditionalPrivilegeIdentityPatchRequestPrivilegeDetails
from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post200_response import ApiV1AdditionalPrivilegeIdentityPermanentPost200Response
from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post200_response_privilege import ApiV1AdditionalPrivilegeIdentityPermanentPost200ResponsePrivilege
from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post_request import ApiV1AdditionalPrivilegeIdentityPermanentPostRequest
from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post_request_privilege_permission import ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermission
from infisicalapi_client.models.api_v1_additional_privilege_identity_permanent_post_request_privilege_permission_conditions import ApiV1AdditionalPrivilegeIdentityPermanentPostRequestPrivilegePermissionConditions
from infisicalapi_client.models.api_v1_additional_privilege_identity_temporary_post_request import ApiV1AdditionalPrivilegeIdentityTemporaryPostRequest
from infisicalapi_client.models.api_v1_additional_privilege_users_get200_response import ApiV1AdditionalPrivilegeUsersGet200Response
from infisicalapi_client.models.api_v1_additional_privilege_users_permanent_post200_response import ApiV1AdditionalPrivilegeUsersPermanentPost200Response
from infisicalapi_client.models.api_v1_additional_privilege_users_permanent_post200_response_privilege import ApiV1AdditionalPrivilegeUsersPermanentPost200ResponsePrivilege
from infisicalapi_client.models.api_v1_additional_privilege_users_permanent_post_request import ApiV1AdditionalPrivilegeUsersPermanentPostRequest
from infisicalapi_client.models.api_v1_additional_privilege_users_privilege_id_patch_request import ApiV1AdditionalPrivilegeUsersPrivilegeIdPatchRequest
from infisicalapi_client.models.api_v1_additional_privilege_users_temporary_post_request import ApiV1AdditionalPrivilegeUsersTemporaryPostRequest
from infisicalapi_client.models.api_v1_admin_config_get200_response import ApiV1AdminConfigGet200Response
from infisicalapi_client.models.api_v1_admin_config_get200_response_config import ApiV1AdminConfigGet200ResponseConfig
from infisicalapi_client.models.api_v1_admin_config_patch200_response import ApiV1AdminConfigPatch200Response
from infisicalapi_client.models.api_v1_admin_config_patch200_response_config import ApiV1AdminConfigPatch200ResponseConfig
from infisicalapi_client.models.api_v1_admin_config_patch_request import ApiV1AdminConfigPatchRequest
from infisicalapi_client.models.api_v1_admin_signup_post200_response import ApiV1AdminSignupPost200Response
from infisicalapi_client.models.api_v1_admin_signup_post_request import ApiV1AdminSignupPostRequest
from infisicalapi_client.models.api_v1_admin_user_management_users_get200_response import ApiV1AdminUserManagementUsersGet200Response
from infisicalapi_client.models.api_v1_admin_user_management_users_get200_response_users_inner import ApiV1AdminUserManagementUsersGet200ResponseUsersInner
from infisicalapi_client.models.api_v1_admin_user_management_users_user_id_delete200_response import ApiV1AdminUserManagementUsersUserIdDelete200Response
from infisicalapi_client.models.api_v1_audit_log_streams_get200_response import ApiV1AuditLogStreamsGet200Response
from infisicalapi_client.models.api_v1_audit_log_streams_get200_response_audit_log_streams_inner import ApiV1AuditLogStreamsGet200ResponseAuditLogStreamsInner
from infisicalapi_client.models.api_v1_audit_log_streams_id_get200_response import ApiV1AuditLogStreamsIdGet200Response
from infisicalapi_client.models.api_v1_audit_log_streams_id_get200_response_audit_log_stream import ApiV1AuditLogStreamsIdGet200ResponseAuditLogStream
from infisicalapi_client.models.api_v1_audit_log_streams_id_get200_response_audit_log_stream_headers_inner import ApiV1AuditLogStreamsIdGet200ResponseAuditLogStreamHeadersInner
from infisicalapi_client.models.api_v1_audit_log_streams_id_patch_request import ApiV1AuditLogStreamsIdPatchRequest
from infisicalapi_client.models.api_v1_audit_log_streams_post200_response import ApiV1AuditLogStreamsPost200Response
from infisicalapi_client.models.api_v1_audit_log_streams_post_request import ApiV1AuditLogStreamsPostRequest
from infisicalapi_client.models.api_v1_audit_log_streams_post_request_headers_inner import ApiV1AuditLogStreamsPostRequestHeadersInner
from infisicalapi_client.models.api_v1_auth_aws_auth_identities_identity_id_get200_response import ApiV1AuthAwsAuthIdentitiesIdentityIdGet200Response
from infisicalapi_client.models.api_v1_auth_aws_auth_identities_identity_id_get200_response_identity_aws_auth import ApiV1AuthAwsAuthIdentitiesIdentityIdGet200ResponseIdentityAwsAuth
from infisicalapi_client.models.api_v1_auth_aws_auth_identities_identity_id_patch_request import ApiV1AuthAwsAuthIdentitiesIdentityIdPatchRequest
from infisicalapi_client.models.api_v1_auth_aws_auth_identities_identity_id_post_request import ApiV1AuthAwsAuthIdentitiesIdentityIdPostRequest
from infisicalapi_client.models.api_v1_auth_aws_auth_login_post_request import ApiV1AuthAwsAuthLoginPostRequest
from infisicalapi_client.models.api_v1_auth_azure_auth_identities_identity_id_get200_response import ApiV1AuthAzureAuthIdentitiesIdentityIdGet200Response
from infisicalapi_client.models.api_v1_auth_azure_auth_identities_identity_id_get200_response_identity_azure_auth import ApiV1AuthAzureAuthIdentitiesIdentityIdGet200ResponseIdentityAzureAuth
from infisicalapi_client.models.api_v1_auth_azure_auth_identities_identity_id_patch_request import ApiV1AuthAzureAuthIdentitiesIdentityIdPatchRequest
from infisicalapi_client.models.api_v1_auth_azure_auth_identities_identity_id_post_request import ApiV1AuthAzureAuthIdentitiesIdentityIdPostRequest
from infisicalapi_client.models.api_v1_auth_check_auth_post200_response import ApiV1AuthCheckAuthPost200Response
from infisicalapi_client.models.api_v1_auth_gcp_auth_identities_identity_id_get200_response import ApiV1AuthGcpAuthIdentitiesIdentityIdGet200Response
from infisicalapi_client.models.api_v1_auth_gcp_auth_identities_identity_id_get200_response_identity_gcp_auth import ApiV1AuthGcpAuthIdentitiesIdentityIdGet200ResponseIdentityGcpAuth
from infisicalapi_client.models.api_v1_auth_gcp_auth_identities_identity_id_patch_request import ApiV1AuthGcpAuthIdentitiesIdentityIdPatchRequest
from infisicalapi_client.models.api_v1_auth_gcp_auth_identities_identity_id_post_request import ApiV1AuthGcpAuthIdentitiesIdentityIdPostRequest
from infisicalapi_client.models.api_v1_auth_kubernetes_auth_identities_identity_id_delete200_response import ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200Response
from infisicalapi_client.models.api_v1_auth_kubernetes_auth_identities_identity_id_delete200_response_identity_kubernetes_auth import ApiV1AuthKubernetesAuthIdentitiesIdentityIdDelete200ResponseIdentityKubernetesAuth
from infisicalapi_client.models.api_v1_auth_kubernetes_auth_identities_identity_id_get200_response import ApiV1AuthKubernetesAuthIdentitiesIdentityIdGet200Response
from infisicalapi_client.models.api_v1_auth_kubernetes_auth_identities_identity_id_get200_response_identity_kubernetes_auth import ApiV1AuthKubernetesAuthIdentitiesIdentityIdGet200ResponseIdentityKubernetesAuth
from infisicalapi_client.models.api_v1_auth_kubernetes_auth_identities_identity_id_patch_request import ApiV1AuthKubernetesAuthIdentitiesIdentityIdPatchRequest
from infisicalapi_client.models.api_v1_auth_kubernetes_auth_identities_identity_id_post_request import ApiV1AuthKubernetesAuthIdentitiesIdentityIdPostRequest
from infisicalapi_client.models.api_v1_auth_kubernetes_auth_login_post_request import ApiV1AuthKubernetesAuthLoginPostRequest
from infisicalapi_client.models.api_v1_auth_oidc_auth_identities_identity_id_delete200_response import ApiV1AuthOidcAuthIdentitiesIdentityIdDelete200Response
from infisicalapi_client.models.api_v1_auth_oidc_auth_identities_identity_id_delete200_response_identity_oidc_auth import ApiV1AuthOidcAuthIdentitiesIdentityIdDelete200ResponseIdentityOidcAuth
from infisicalapi_client.models.api_v1_auth_oidc_auth_identities_identity_id_get200_response import ApiV1AuthOidcAuthIdentitiesIdentityIdGet200Response
from infisicalapi_client.models.api_v1_auth_oidc_auth_identities_identity_id_get200_response_identity_oidc_auth import ApiV1AuthOidcAuthIdentitiesIdentityIdGet200ResponseIdentityOidcAuth
from infisicalapi_client.models.api_v1_auth_oidc_auth_identities_identity_id_patch_request import ApiV1AuthOidcAuthIdentitiesIdentityIdPatchRequest
from infisicalapi_client.models.api_v1_auth_oidc_auth_identities_identity_id_post_request import ApiV1AuthOidcAuthIdentitiesIdentityIdPostRequest
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_get200_response import ApiV1AuthTokenAuthIdentitiesIdentityIdGet200Response
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_get200_response_identity_token_auth import ApiV1AuthTokenAuthIdentitiesIdentityIdGet200ResponseIdentityTokenAuth
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_patch_request import ApiV1AuthTokenAuthIdentitiesIdentityIdPatchRequest
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_post_request import ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequest
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_post_request_access_token_trusted_ips_inner import ApiV1AuthTokenAuthIdentitiesIdentityIdPostRequestAccessTokenTrustedIpsInner
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_tokens_get200_response import ApiV1AuthTokenAuthIdentitiesIdentityIdTokensGet200Response
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_tokens_get200_response_tokens_inner import ApiV1AuthTokenAuthIdentitiesIdentityIdTokensGet200ResponseTokensInner
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_tokens_post200_response import ApiV1AuthTokenAuthIdentitiesIdentityIdTokensPost200Response
from infisicalapi_client.models.api_v1_auth_token_auth_identities_identity_id_tokens_post_request import ApiV1AuthTokenAuthIdentitiesIdentityIdTokensPostRequest
from infisicalapi_client.models.api_v1_auth_token_auth_tokens_token_id_patch200_response import ApiV1AuthTokenAuthTokensTokenIdPatch200Response
from infisicalapi_client.models.api_v1_auth_token_auth_tokens_token_id_patch_request import ApiV1AuthTokenAuthTokensTokenIdPatchRequest
from infisicalapi_client.models.api_v1_auth_token_post200_response import ApiV1AuthTokenPost200Response
from infisicalapi_client.models.api_v1_auth_token_renew_post_request import ApiV1AuthTokenRenewPostRequest
from infisicalapi_client.models.api_v1_auth_token_revoke_post_request import ApiV1AuthTokenRevokePostRequest
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_client_secrets_client_secret_id_get200_response import ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsClientSecretIdGet200Response
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_client_secrets_get200_response import ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200Response
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_client_secrets_get200_response_client_secret_data_inner import ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsGet200ResponseClientSecretDataInner
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_client_secrets_post200_response import ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsPost200Response
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_client_secrets_post_request import ApiV1AuthUniversalAuthIdentitiesIdentityIdClientSecretsPostRequest
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_get200_response import ApiV1AuthUniversalAuthIdentitiesIdentityIdGet200Response
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_get200_response_identity_universal_auth import ApiV1AuthUniversalAuthIdentitiesIdentityIdGet200ResponseIdentityUniversalAuth
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_patch_request import ApiV1AuthUniversalAuthIdentitiesIdentityIdPatchRequest
from infisicalapi_client.models.api_v1_auth_universal_auth_identities_identity_id_post_request import ApiV1AuthUniversalAuthIdentitiesIdentityIdPostRequest
from infisicalapi_client.models.api_v1_auth_universal_auth_login_post_request import ApiV1AuthUniversalAuthLoginPostRequest
from infisicalapi_client.models.api_v1_bot_bot_id_active_patch_request import ApiV1BotBotIdActivePatchRequest
from infisicalapi_client.models.api_v1_bot_bot_id_active_patch_request_bot_key import ApiV1BotBotIdActivePatchRequestBotKey
from infisicalapi_client.models.api_v1_bot_project_id_get200_response import ApiV1BotProjectIdGet200Response
from infisicalapi_client.models.api_v1_bot_project_id_get200_response_bot import ApiV1BotProjectIdGet200ResponseBot
from infisicalapi_client.models.api_v1_dynamic_secrets_get200_response import ApiV1DynamicSecretsGet200Response
from infisicalapi_client.models.api_v1_dynamic_secrets_get200_response_dynamic_secrets_inner import ApiV1DynamicSecretsGet200ResponseDynamicSecretsInner
from infisicalapi_client.models.api_v1_dynamic_secrets_leases_lease_id_delete200_response import ApiV1DynamicSecretsLeasesLeaseIdDelete200Response
from infisicalapi_client.models.api_v1_dynamic_secrets_leases_lease_id_delete_request import ApiV1DynamicSecretsLeasesLeaseIdDeleteRequest
from infisicalapi_client.models.api_v1_dynamic_secrets_leases_lease_id_get200_response import ApiV1DynamicSecretsLeasesLeaseIdGet200Response
from infisicalapi_client.models.api_v1_dynamic_secrets_leases_lease_id_get200_response_lease import ApiV1DynamicSecretsLeasesLeaseIdGet200ResponseLease
from infisicalapi_client.models.api_v1_dynamic_secrets_leases_lease_id_renew_post_request import ApiV1DynamicSecretsLeasesLeaseIdRenewPostRequest
from infisicalapi_client.models.api_v1_dynamic_secrets_leases_post200_response import ApiV1DynamicSecretsLeasesPost200Response
from infisicalapi_client.models.api_v1_dynamic_secrets_leases_post_request import ApiV1DynamicSecretsLeasesPostRequest
from infisicalapi_client.models.api_v1_dynamic_secrets_name_delete_request import ApiV1DynamicSecretsNameDeleteRequest
from infisicalapi_client.models.api_v1_dynamic_secrets_name_get200_response import ApiV1DynamicSecretsNameGet200Response
from infisicalapi_client.models.api_v1_dynamic_secrets_name_get200_response_dynamic_secret import ApiV1DynamicSecretsNameGet200ResponseDynamicSecret
from infisicalapi_client.models.api_v1_dynamic_secrets_name_leases_get200_response import ApiV1DynamicSecretsNameLeasesGet200Response
from infisicalapi_client.models.api_v1_dynamic_secrets_name_leases_get200_response_leases_inner import ApiV1DynamicSecretsNameLeasesGet200ResponseLeasesInner
from infisicalapi_client.models.api_v1_dynamic_secrets_name_patch_request import ApiV1DynamicSecretsNamePatchRequest
from infisicalapi_client.models.api_v1_dynamic_secrets_name_patch_request_data import ApiV1DynamicSecretsNamePatchRequestData
from infisicalapi_client.models.api_v1_dynamic_secrets_post200_response import ApiV1DynamicSecretsPost200Response
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request import ApiV1DynamicSecretsPostRequest
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request_provider import ApiV1DynamicSecretsPostRequestProvider
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request_provider_any_of import ApiV1DynamicSecretsPostRequestProviderAnyOf
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request_provider_any_of1 import ApiV1DynamicSecretsPostRequestProviderAnyOf1
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request_provider_any_of1_inputs import ApiV1DynamicSecretsPostRequestProviderAnyOf1Inputs
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request_provider_any_of2 import ApiV1DynamicSecretsPostRequestProviderAnyOf2
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request_provider_any_of2_inputs import ApiV1DynamicSecretsPostRequestProviderAnyOf2Inputs
from infisicalapi_client.models.api_v1_dynamic_secrets_post_request_provider_any_of_inputs import ApiV1DynamicSecretsPostRequestProviderAnyOfInputs
from infisicalapi_client.models.api_v1_external_kms_get200_response import ApiV1ExternalKmsGet200Response
from infisicalapi_client.models.api_v1_external_kms_get200_response_external_kms_list_inner import ApiV1ExternalKmsGet200ResponseExternalKmsListInner
from infisicalapi_client.models.api_v1_external_kms_get200_response_external_kms_list_inner_external_kms import ApiV1ExternalKmsGet200ResponseExternalKmsListInnerExternalKms
from infisicalapi_client.models.api_v1_external_kms_id_get200_response import ApiV1ExternalKmsIdGet200Response
from infisicalapi_client.models.api_v1_external_kms_id_get200_response_external_kms import ApiV1ExternalKmsIdGet200ResponseExternalKms
from infisicalapi_client.models.api_v1_external_kms_id_get200_response_external_kms_external import ApiV1ExternalKmsIdGet200ResponseExternalKmsExternal
from infisicalapi_client.models.api_v1_external_kms_id_patch_request import ApiV1ExternalKmsIdPatchRequest
from infisicalapi_client.models.api_v1_external_kms_id_patch_request_provider import ApiV1ExternalKmsIdPatchRequestProvider
from infisicalapi_client.models.api_v1_external_kms_id_patch_request_provider_inputs import ApiV1ExternalKmsIdPatchRequestProviderInputs
from infisicalapi_client.models.api_v1_external_kms_post200_response import ApiV1ExternalKmsPost200Response
from infisicalapi_client.models.api_v1_external_kms_post200_response_external_kms import ApiV1ExternalKmsPost200ResponseExternalKms
from infisicalapi_client.models.api_v1_external_kms_post200_response_external_kms_external import ApiV1ExternalKmsPost200ResponseExternalKmsExternal
from infisicalapi_client.models.api_v1_external_kms_post_request import ApiV1ExternalKmsPostRequest
from infisicalapi_client.models.api_v1_external_kms_post_request_provider import ApiV1ExternalKmsPostRequestProvider
from infisicalapi_client.models.api_v1_external_kms_post_request_provider_inputs import ApiV1ExternalKmsPostRequestProviderInputs
from infisicalapi_client.models.api_v1_external_kms_post_request_provider_inputs_credential import ApiV1ExternalKmsPostRequestProviderInputsCredential
from infisicalapi_client.models.api_v1_external_kms_post_request_provider_inputs_credential_any_of import ApiV1ExternalKmsPostRequestProviderInputsCredentialAnyOf
from infisicalapi_client.models.api_v1_external_kms_post_request_provider_inputs_credential_any_of1 import ApiV1ExternalKmsPostRequestProviderInputsCredentialAnyOf1
from infisicalapi_client.models.api_v1_external_kms_post_request_provider_inputs_credential_any_of1_data import ApiV1ExternalKmsPostRequestProviderInputsCredentialAnyOf1Data
from infisicalapi_client.models.api_v1_external_kms_post_request_provider_inputs_credential_any_of_data import ApiV1ExternalKmsPostRequestProviderInputsCredentialAnyOfData
from infisicalapi_client.models.api_v1_folders_batch_patch_request import ApiV1FoldersBatchPatchRequest
from infisicalapi_client.models.api_v1_folders_batch_patch_request_folders_inner import ApiV1FoldersBatchPatchRequestFoldersInner
from infisicalapi_client.models.api_v1_folders_folder_id_or_name_delete_request import ApiV1FoldersFolderIdOrNameDeleteRequest
from infisicalapi_client.models.api_v1_folders_folder_id_patch_request import ApiV1FoldersFolderIdPatchRequest
from infisicalapi_client.models.api_v1_folders_get200_response import ApiV1FoldersGet200Response
from infisicalapi_client.models.api_v1_folders_get200_response_folders_inner import ApiV1FoldersGet200ResponseFoldersInner
from infisicalapi_client.models.api_v1_folders_post200_response import ApiV1FoldersPost200Response
from infisicalapi_client.models.api_v1_folders_post_request import ApiV1FoldersPostRequest
from infisicalapi_client.models.api_v1_groups_current_slug_patch_request import ApiV1GroupsCurrentSlugPatchRequest
from infisicalapi_client.models.api_v1_groups_post200_response import ApiV1GroupsPost200Response
from infisicalapi_client.models.api_v1_groups_post_request import ApiV1GroupsPostRequest
from infisicalapi_client.models.api_v1_groups_slug_users_get200_response import ApiV1GroupsSlugUsersGet200Response
from infisicalapi_client.models.api_v1_groups_slug_users_get200_response_users_inner import ApiV1GroupsSlugUsersGet200ResponseUsersInner
from infisicalapi_client.models.api_v1_groups_slug_users_username_post200_response import ApiV1GroupsSlugUsersUsernamePost200Response
from infisicalapi_client.models.api_v1_identities_get200_response import ApiV1IdentitiesGet200Response
from infisicalapi_client.models.api_v1_identities_get200_response_identities_inner import ApiV1IdentitiesGet200ResponseIdentitiesInner
from infisicalapi_client.models.api_v1_identities_get200_response_identities_inner_identity import ApiV1IdentitiesGet200ResponseIdentitiesInnerIdentity
from infisicalapi_client.models.api_v1_identities_identity_id_get200_response import ApiV1IdentitiesIdentityIdGet200Response
from infisicalapi_client.models.api_v1_identities_identity_id_identity_memberships_get200_response import ApiV1IdentitiesIdentityIdIdentityMembershipsGet200Response
from infisicalapi_client.models.api_v1_identities_identity_id_identity_memberships_get200_response_identity_memberships_inner import ApiV1IdentitiesIdentityIdIdentityMembershipsGet200ResponseIdentityMembershipsInner
from infisicalapi_client.models.api_v1_identities_identity_id_patch_request import ApiV1IdentitiesIdentityIdPatchRequest
from infisicalapi_client.models.api_v1_identities_post200_response import ApiV1IdentitiesPost200Response
from infisicalapi_client.models.api_v1_identities_post200_response_identity import ApiV1IdentitiesPost200ResponseIdentity
from infisicalapi_client.models.api_v1_identities_post_request import ApiV1IdentitiesPostRequest
from infisicalapi_client.models.api_v1_integration_auth_access_token_post_request import ApiV1IntegrationAuthAccessTokenPostRequest
from infisicalapi_client.models.api_v1_integration_auth_delete200_response import ApiV1IntegrationAuthDelete200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_apps_get200_response import ApiV1IntegrationAuthIntegrationAuthIdAppsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_apps_get200_response_apps_inner import ApiV1IntegrationAuthIntegrationAuthIdAppsGet200ResponseAppsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_aws_secrets_manager_kms_keys_get200_response import ApiV1IntegrationAuthIntegrationAuthIdAwsSecretsManagerKmsKeysGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_aws_secrets_manager_kms_keys_get200_response_kms_keys_inner import ApiV1IntegrationAuthIntegrationAuthIdAwsSecretsManagerKmsKeysGet200ResponseKmsKeysInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_bitbucket_workspaces_get200_response import ApiV1IntegrationAuthIntegrationAuthIdBitbucketWorkspacesGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_bitbucket_workspaces_get200_response_workspaces_inner import ApiV1IntegrationAuthIntegrationAuthIdBitbucketWorkspacesGet200ResponseWorkspacesInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_checkly_groups_get200_response import ApiV1IntegrationAuthIntegrationAuthIdChecklyGroupsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_checkly_groups_get200_response_groups_inner import ApiV1IntegrationAuthIntegrationAuthIdChecklyGroupsGet200ResponseGroupsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_get200_response import ApiV1IntegrationAuthIntegrationAuthIdGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_github_envs_get200_response import ApiV1IntegrationAuthIntegrationAuthIdGithubEnvsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_github_envs_get200_response_envs_inner import ApiV1IntegrationAuthIntegrationAuthIdGithubEnvsGet200ResponseEnvsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_github_orgs_get200_response import ApiV1IntegrationAuthIntegrationAuthIdGithubOrgsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_github_orgs_get200_response_orgs_inner import ApiV1IntegrationAuthIntegrationAuthIdGithubOrgsGet200ResponseOrgsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_heroku_pipelines_get200_response import ApiV1IntegrationAuthIntegrationAuthIdHerokuPipelinesGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_heroku_pipelines_get200_response_pipelines_inner import ApiV1IntegrationAuthIntegrationAuthIdHerokuPipelinesGet200ResponsePipelinesInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_heroku_pipelines_get200_response_pipelines_inner_app import ApiV1IntegrationAuthIntegrationAuthIdHerokuPipelinesGet200ResponsePipelinesInnerApp
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_heroku_pipelines_get200_response_pipelines_inner_pipeline import ApiV1IntegrationAuthIntegrationAuthIdHerokuPipelinesGet200ResponsePipelinesInnerPipeline
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_northflank_secret_groups_get200_response import ApiV1IntegrationAuthIntegrationAuthIdNorthflankSecretGroupsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_northflank_secret_groups_get200_response_secret_groups_inner import ApiV1IntegrationAuthIntegrationAuthIdNorthflankSecretGroupsGet200ResponseSecretGroupsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_qovery_apps_get200_response import ApiV1IntegrationAuthIntegrationAuthIdQoveryAppsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_qovery_apps_get200_response_apps_inner import ApiV1IntegrationAuthIntegrationAuthIdQoveryAppsGet200ResponseAppsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_qovery_containers_get200_response import ApiV1IntegrationAuthIntegrationAuthIdQoveryContainersGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_qovery_environments_get200_response import ApiV1IntegrationAuthIntegrationAuthIdQoveryEnvironmentsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_qovery_environments_get200_response_environments_inner import ApiV1IntegrationAuthIntegrationAuthIdQoveryEnvironmentsGet200ResponseEnvironmentsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_qovery_jobs_get200_response import ApiV1IntegrationAuthIntegrationAuthIdQoveryJobsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_qovery_projects_get200_response import ApiV1IntegrationAuthIntegrationAuthIdQoveryProjectsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_qovery_projects_get200_response_projects_inner import ApiV1IntegrationAuthIntegrationAuthIdQoveryProjectsGet200ResponseProjectsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_railway_services_get200_response import ApiV1IntegrationAuthIntegrationAuthIdRailwayServicesGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_railway_services_get200_response_services_inner import ApiV1IntegrationAuthIntegrationAuthIdRailwayServicesGet200ResponseServicesInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_teamcity_build_configs_get200_response import ApiV1IntegrationAuthIntegrationAuthIdTeamcityBuildConfigsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_teamcity_build_configs_get200_response_build_configs_inner import ApiV1IntegrationAuthIntegrationAuthIdTeamcityBuildConfigsGet200ResponseBuildConfigsInner
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_teams_get200_response import ApiV1IntegrationAuthIntegrationAuthIdTeamsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_auth_id_vercel_branches_get200_response import ApiV1IntegrationAuthIntegrationAuthIdVercelBranchesGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_options_get200_response import ApiV1IntegrationAuthIntegrationOptionsGet200Response
from infisicalapi_client.models.api_v1_integration_auth_integration_options_get200_response_integration_options_inner import ApiV1IntegrationAuthIntegrationOptionsGet200ResponseIntegrationOptionsInner
from infisicalapi_client.models.api_v1_integration_auth_oauth_token_post_request import ApiV1IntegrationAuthOauthTokenPostRequest
from infisicalapi_client.models.api_v1_integration_integration_id_patch_request import ApiV1IntegrationIntegrationIdPatchRequest
from infisicalapi_client.models.api_v1_integration_integration_id_patch_request_metadata import ApiV1IntegrationIntegrationIdPatchRequestMetadata
from infisicalapi_client.models.api_v1_integration_post200_response import ApiV1IntegrationPost200Response
from infisicalapi_client.models.api_v1_integration_post200_response_integration import ApiV1IntegrationPost200ResponseIntegration
from infisicalapi_client.models.api_v1_integration_post_request import ApiV1IntegrationPostRequest
from infisicalapi_client.models.api_v1_integration_post_request_metadata import ApiV1IntegrationPostRequestMetadata
from infisicalapi_client.models.api_v1_integration_post_request_metadata_secret_gcp_label import ApiV1IntegrationPostRequestMetadataSecretGCPLabel
from infisicalapi_client.models.api_v1_invite_org_signup_post200_response import ApiV1InviteOrgSignupPost200Response
from infisicalapi_client.models.api_v1_invite_org_signup_post_request import ApiV1InviteOrgSignupPostRequest
from infisicalapi_client.models.api_v1_invite_org_verify_post200_response import ApiV1InviteOrgVerifyPost200Response
from infisicalapi_client.models.api_v1_invite_org_verify_post_request import ApiV1InviteOrgVerifyPostRequest
from infisicalapi_client.models.api_v1_ldap_config_config_id_group_maps_get200_response_inner import ApiV1LdapConfigConfigIdGroupMapsGet200ResponseInner
from infisicalapi_client.models.api_v1_ldap_config_config_id_group_maps_post200_response import ApiV1LdapConfigConfigIdGroupMapsPost200Response
from infisicalapi_client.models.api_v1_ldap_config_config_id_group_maps_post_request import ApiV1LdapConfigConfigIdGroupMapsPostRequest
from infisicalapi_client.models.api_v1_ldap_config_get200_response import ApiV1LdapConfigGet200Response
from infisicalapi_client.models.api_v1_ldap_config_patch_request import ApiV1LdapConfigPatchRequest
from infisicalapi_client.models.api_v1_ldap_config_post200_response import ApiV1LdapConfigPost200Response
from infisicalapi_client.models.api_v1_ldap_config_post_request import ApiV1LdapConfigPostRequest
from infisicalapi_client.models.api_v1_ldap_login_post_request import ApiV1LdapLoginPostRequest
from infisicalapi_client.models.api_v1_organization_admin_projects_get200_response import ApiV1OrganizationAdminProjectsGet200Response
from infisicalapi_client.models.api_v1_organization_admin_projects_get200_response_projects_inner import ApiV1OrganizationAdminProjectsGet200ResponseProjectsInner
from infisicalapi_client.models.api_v1_organization_admin_projects_project_id_grant_admin_access_post200_response import ApiV1OrganizationAdminProjectsProjectIdGrantAdminAccessPost200Response
from infisicalapi_client.models.api_v1_organization_admin_projects_project_id_grant_admin_access_post200_response_membership import ApiV1OrganizationAdminProjectsProjectIdGrantAdminAccessPost200ResponseMembership
from infisicalapi_client.models.api_v1_organization_get200_response import ApiV1OrganizationGet200Response
from infisicalapi_client.models.api_v1_organization_get200_response_organizations_inner import ApiV1OrganizationGet200ResponseOrganizationsInner
from infisicalapi_client.models.api_v1_organization_organization_id_get200_response import ApiV1OrganizationOrganizationIdGet200Response
from infisicalapi_client.models.api_v1_organization_organization_id_groups_get200_response import ApiV1OrganizationOrganizationIdGroupsGet200Response
from infisicalapi_client.models.api_v1_organization_organization_id_groups_get200_response_groups_inner import ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInner
from infisicalapi_client.models.api_v1_organization_organization_id_groups_get200_response_groups_inner_custom_role import ApiV1OrganizationOrganizationIdGroupsGet200ResponseGroupsInnerCustomRole
from infisicalapi_client.models.api_v1_organization_organization_id_incident_contact_org_get200_response import ApiV1OrganizationOrganizationIdIncidentContactOrgGet200Response
from infisicalapi_client.models.api_v1_organization_organization_id_incident_contact_org_get200_response_incident_contacts_org_inner import ApiV1OrganizationOrganizationIdIncidentContactOrgGet200ResponseIncidentContactsOrgInner
from infisicalapi_client.models.api_v1_organization_organization_id_incident_contact_org_post200_response import ApiV1OrganizationOrganizationIdIncidentContactOrgPost200Response
from infisicalapi_client.models.api_v1_organization_organization_id_patch200_response import ApiV1OrganizationOrganizationIdPatch200Response
from infisicalapi_client.models.api_v1_organization_organization_id_patch_request import ApiV1OrganizationOrganizationIdPatchRequest
from infisicalapi_client.models.api_v1_organization_organization_id_permissions_get200_response import ApiV1OrganizationOrganizationIdPermissionsGet200Response
from infisicalapi_client.models.api_v1_organization_organization_id_permissions_get200_response_membership import ApiV1OrganizationOrganizationIdPermissionsGet200ResponseMembership
from infisicalapi_client.models.api_v1_organization_organization_id_roles_get200_response import ApiV1OrganizationOrganizationIdRolesGet200Response
from infisicalapi_client.models.api_v1_organization_organization_id_roles_get200_response_data import ApiV1OrganizationOrganizationIdRolesGet200ResponseData
from infisicalapi_client.models.api_v1_organization_organization_id_roles_get200_response_data_roles_inner import ApiV1OrganizationOrganizationIdRolesGet200ResponseDataRolesInner
from infisicalapi_client.models.api_v1_organization_organization_id_roles_post200_response import ApiV1OrganizationOrganizationIdRolesPost200Response
from infisicalapi_client.models.api_v1_organization_organization_id_roles_post200_response_role import ApiV1OrganizationOrganizationIdRolesPost200ResponseRole
from infisicalapi_client.models.api_v1_organization_organization_id_roles_post_request import ApiV1OrganizationOrganizationIdRolesPostRequest
from infisicalapi_client.models.api_v1_organization_organization_id_roles_role_id_patch_request import ApiV1OrganizationOrganizationIdRolesRoleIdPatchRequest
from infisicalapi_client.models.api_v1_organization_organization_id_users_get200_response import ApiV1OrganizationOrganizationIdUsersGet200Response
from infisicalapi_client.models.api_v1_organization_organization_id_users_get200_response_users_inner import ApiV1OrganizationOrganizationIdUsersGet200ResponseUsersInner
from infisicalapi_client.models.api_v1_organization_organization_id_users_get200_response_users_inner_user import ApiV1OrganizationOrganizationIdUsersGet200ResponseUsersInnerUser
from infisicalapi_client.models.api_v1_organizations_organization_id_billing_details_patch_request import ApiV1OrganizationsOrganizationIdBillingDetailsPatchRequest
from infisicalapi_client.models.api_v1_organizations_organization_id_billing_details_payment_methods_post_request import ApiV1OrganizationsOrganizationIdBillingDetailsPaymentMethodsPostRequest
from infisicalapi_client.models.api_v1_organizations_organization_id_billing_details_tax_ids_post_request import ApiV1OrganizationsOrganizationIdBillingDetailsTaxIdsPostRequest
from infisicalapi_client.models.api_v1_organizations_organization_id_plan_get200_response import ApiV1OrganizationsOrganizationIdPlanGet200Response
from infisicalapi_client.models.api_v1_organizations_organization_id_session_trial_post_request import ApiV1OrganizationsOrganizationIdSessionTrialPostRequest
from infisicalapi_client.models.api_v1_password_backup_private_key_get200_response import ApiV1PasswordBackupPrivateKeyGet200Response
from infisicalapi_client.models.api_v1_password_backup_private_key_get200_response_backup_private_key import ApiV1PasswordBackupPrivateKeyGet200ResponseBackupPrivateKey
from infisicalapi_client.models.api_v1_password_backup_private_key_post_request import ApiV1PasswordBackupPrivateKeyPostRequest
from infisicalapi_client.models.api_v1_password_change_password_post_request import ApiV1PasswordChangePasswordPostRequest
from infisicalapi_client.models.api_v1_password_email_password_reset_post_request import ApiV1PasswordEmailPasswordResetPostRequest
from infisicalapi_client.models.api_v1_password_email_password_reset_verify_post200_response import ApiV1PasswordEmailPasswordResetVerifyPost200Response
from infisicalapi_client.models.api_v1_password_email_password_reset_verify_post200_response_user import ApiV1PasswordEmailPasswordResetVerifyPost200ResponseUser
from infisicalapi_client.models.api_v1_password_email_password_reset_verify_post_request import ApiV1PasswordEmailPasswordResetVerifyPostRequest
from infisicalapi_client.models.api_v1_password_password_reset_post_request import ApiV1PasswordPasswordResetPostRequest
from infisicalapi_client.models.api_v1_password_srp1_post200_response import ApiV1PasswordSrp1Post200Response
from infisicalapi_client.models.api_v1_password_srp1_post_request import ApiV1PasswordSrp1PostRequest
from infisicalapi_client.models.api_v1_pki_ca_ca_id_certificate_get200_response import ApiV1PkiCaCaIdCertificateGet200Response
from infisicalapi_client.models.api_v1_pki_ca_ca_id_crl_get200_response import ApiV1PkiCaCaIdCrlGet200Response
from infisicalapi_client.models.api_v1_pki_ca_ca_id_csr_get200_response import ApiV1PkiCaCaIdCsrGet200Response
from infisicalapi_client.models.api_v1_pki_ca_ca_id_import_certificate_post200_response import ApiV1PkiCaCaIdImportCertificatePost200Response
from infisicalapi_client.models.api_v1_pki_ca_ca_id_import_certificate_post_request import ApiV1PkiCaCaIdImportCertificatePostRequest
from infisicalapi_client.models.api_v1_pki_ca_ca_id_issue_certificate_post200_response import ApiV1PkiCaCaIdIssueCertificatePost200Response
from infisicalapi_client.models.api_v1_pki_ca_ca_id_issue_certificate_post_request import ApiV1PkiCaCaIdIssueCertificatePostRequest
from infisicalapi_client.models.api_v1_pki_ca_ca_id_patch_request import ApiV1PkiCaCaIdPatchRequest
from infisicalapi_client.models.api_v1_pki_ca_ca_id_sign_certificate_post200_response import ApiV1PkiCaCaIdSignCertificatePost200Response
from infisicalapi_client.models.api_v1_pki_ca_ca_id_sign_certificate_post_request import ApiV1PkiCaCaIdSignCertificatePostRequest
from infisicalapi_client.models.api_v1_pki_ca_ca_id_sign_intermediate_post200_response import ApiV1PkiCaCaIdSignIntermediatePost200Response
from infisicalapi_client.models.api_v1_pki_ca_ca_id_sign_intermediate_post_request import ApiV1PkiCaCaIdSignIntermediatePostRequest
from infisicalapi_client.models.api_v1_pki_ca_post200_response import ApiV1PkiCaPost200Response
from infisicalapi_client.models.api_v1_pki_ca_post200_response_ca import ApiV1PkiCaPost200ResponseCa
from infisicalapi_client.models.api_v1_pki_ca_post_request import ApiV1PkiCaPostRequest
from infisicalapi_client.models.api_v1_pki_certificates_serial_number_certificate_get200_response import ApiV1PkiCertificatesSerialNumberCertificateGet200Response
from infisicalapi_client.models.api_v1_pki_certificates_serial_number_get200_response import ApiV1PkiCertificatesSerialNumberGet200Response
from infisicalapi_client.models.api_v1_pki_certificates_serial_number_get200_response_certificate import ApiV1PkiCertificatesSerialNumberGet200ResponseCertificate
from infisicalapi_client.models.api_v1_pki_certificates_serial_number_revoke_post200_response import ApiV1PkiCertificatesSerialNumberRevokePost200Response
from infisicalapi_client.models.api_v1_pki_certificates_serial_number_revoke_post_request import ApiV1PkiCertificatesSerialNumberRevokePostRequest
from infisicalapi_client.models.api_v1_rate_limit_get200_response import ApiV1RateLimitGet200Response
from infisicalapi_client.models.api_v1_rate_limit_get200_response_rate_limit import ApiV1RateLimitGet200ResponseRateLimit
from infisicalapi_client.models.api_v1_rate_limit_put_request import ApiV1RateLimitPutRequest
from infisicalapi_client.models.api_v1_scim_groups_get200_response import ApiV1ScimGroupsGet200Response
from infisicalapi_client.models.api_v1_scim_groups_get200_response_resources_inner import ApiV1ScimGroupsGet200ResponseResourcesInner
from infisicalapi_client.models.api_v1_scim_groups_get200_response_resources_inner_meta import ApiV1ScimGroupsGet200ResponseResourcesInnerMeta
from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request import ApiV1ScimGroupsGroupIdPatchRequest
from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request_operations_inner import ApiV1ScimGroupsGroupIdPatchRequestOperationsInner
from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request_operations_inner_any_of import ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf
from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request_operations_inner_any_of1 import ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf1
from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request_operations_inner_any_of2 import ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf2
from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request_operations_inner_any_of2_value_inner import ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOf2ValueInner
from infisicalapi_client.models.api_v1_scim_groups_group_id_patch_request_operations_inner_any_of_value import ApiV1ScimGroupsGroupIdPatchRequestOperationsInnerAnyOfValue
from infisicalapi_client.models.api_v1_scim_groups_group_id_put_request import ApiV1ScimGroupsGroupIdPutRequest
from infisicalapi_client.models.api_v1_scim_groups_post200_response import ApiV1ScimGroupsPost200Response
from infisicalapi_client.models.api_v1_scim_groups_post_request import ApiV1ScimGroupsPostRequest
from infisicalapi_client.models.api_v1_scim_scim_tokens_get200_response import ApiV1ScimScimTokensGet200Response
from infisicalapi_client.models.api_v1_scim_scim_tokens_get200_response_scim_tokens_inner import ApiV1ScimScimTokensGet200ResponseScimTokensInner
from infisicalapi_client.models.api_v1_scim_scim_tokens_post200_response import ApiV1ScimScimTokensPost200Response
from infisicalapi_client.models.api_v1_scim_scim_tokens_post_request import ApiV1ScimScimTokensPostRequest
from infisicalapi_client.models.api_v1_scim_scim_tokens_scim_token_id_delete200_response import ApiV1ScimScimTokensScimTokenIdDelete200Response
from infisicalapi_client.models.api_v1_scim_users_get200_response import ApiV1ScimUsersGet200Response
from infisicalapi_client.models.api_v1_scim_users_get200_response_resources_inner import ApiV1ScimUsersGet200ResponseResourcesInner
from infisicalapi_client.models.api_v1_scim_users_get200_response_resources_inner_emails_inner import ApiV1ScimUsersGet200ResponseResourcesInnerEmailsInner
from infisicalapi_client.models.api_v1_scim_users_get200_response_resources_inner_name import ApiV1ScimUsersGet200ResponseResourcesInnerName
from infisicalapi_client.models.api_v1_scim_users_org_membership_id_get201_response import ApiV1ScimUsersOrgMembershipIdGet201Response
from infisicalapi_client.models.api_v1_scim_users_org_membership_id_get201_response_groups_inner import ApiV1ScimUsersOrgMembershipIdGet201ResponseGroupsInner
from infisicalapi_client.models.api_v1_scim_users_org_membership_id_put200_response import ApiV1ScimUsersOrgMembershipIdPut200Response
from infisicalapi_client.models.api_v1_scim_users_org_membership_id_put_request import ApiV1ScimUsersOrgMembershipIdPutRequest
from infisicalapi_client.models.api_v1_scim_users_post200_response import ApiV1ScimUsersPost200Response
from infisicalapi_client.models.api_v1_scim_users_post_request import ApiV1ScimUsersPostRequest
from infisicalapi_client.models.api_v1_scim_users_post_request_emails_inner import ApiV1ScimUsersPostRequestEmailsInner
from infisicalapi_client.models.api_v1_secret_approval_requests_count_get200_response import ApiV1SecretApprovalRequestsCountGet200Response
from infisicalapi_client.models.api_v1_secret_approval_requests_count_get200_response_approvals import ApiV1SecretApprovalRequestsCountGet200ResponseApprovals
from infisicalapi_client.models.api_v1_secret_approval_requests_get200_response import ApiV1SecretApprovalRequestsGet200Response
from infisicalapi_client.models.api_v1_secret_approval_requests_get200_response_approvals_inner import ApiV1SecretApprovalRequestsGet200ResponseApprovalsInner
from infisicalapi_client.models.api_v1_secret_approval_requests_get200_response_approvals_inner_commits_inner import ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitsInner
from infisicalapi_client.models.api_v1_secret_approval_requests_get200_response_approvals_inner_committer_user import ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerCommitterUser
from infisicalapi_client.models.api_v1_secret_approval_requests_get200_response_approvals_inner_policy import ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerPolicy
from infisicalapi_client.models.api_v1_secret_approval_requests_get200_response_approvals_inner_reviewers_inner import ApiV1SecretApprovalRequestsGet200ResponseApprovalsInnerReviewersInner
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response import ApiV1SecretApprovalRequestsIdGet200Response
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval import ApiV1SecretApprovalRequestsIdGet200ResponseApproval
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval_commits_inner import ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInner
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval_commits_inner_secret import ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInnerSecret
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval_commits_inner_secret_version import ApiV1SecretApprovalRequestsIdGet200ResponseApprovalCommitsInnerSecretVersion
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval_policy import ApiV1SecretApprovalRequestsIdGet200ResponseApprovalPolicy
from infisicalapi_client.models.api_v1_secret_approval_requests_id_get200_response_approval_reviewers_inner import ApiV1SecretApprovalRequestsIdGet200ResponseApprovalReviewersInner
from infisicalapi_client.models.api_v1_secret_approval_requests_id_merge_post200_response import ApiV1SecretApprovalRequestsIdMergePost200Response
from infisicalapi_client.models.api_v1_secret_approval_requests_id_merge_post200_response_approval import ApiV1SecretApprovalRequestsIdMergePost200ResponseApproval
from infisicalapi_client.models.api_v1_secret_approval_requests_id_merge_post_request import ApiV1SecretApprovalRequestsIdMergePostRequest
from infisicalapi_client.models.api_v1_secret_approval_requests_id_review_post200_response import ApiV1SecretApprovalRequestsIdReviewPost200Response
from infisicalapi_client.models.api_v1_secret_approval_requests_id_review_post200_response_review import ApiV1SecretApprovalRequestsIdReviewPost200ResponseReview
from infisicalapi_client.models.api_v1_secret_approval_requests_id_review_post_request import ApiV1SecretApprovalRequestsIdReviewPostRequest
from infisicalapi_client.models.api_v1_secret_approval_requests_id_status_post_request import ApiV1SecretApprovalRequestsIdStatusPostRequest
from infisicalapi_client.models.api_v1_secret_approvals_board_get200_response import ApiV1SecretApprovalsBoardGet200Response
from infisicalapi_client.models.api_v1_secret_approvals_get200_response import ApiV1SecretApprovalsGet200Response
from infisicalapi_client.models.api_v1_secret_approvals_get200_response_approvals_inner import ApiV1SecretApprovalsGet200ResponseApprovalsInner
from infisicalapi_client.models.api_v1_secret_approvals_get200_response_approvals_inner_environment import ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment
from infisicalapi_client.models.api_v1_secret_approvals_get200_response_approvals_inner_user_approvers_inner import ApiV1SecretApprovalsGet200ResponseApprovalsInnerUserApproversInner
from infisicalapi_client.models.api_v1_secret_approvals_post200_response import ApiV1SecretApprovalsPost200Response
from infisicalapi_client.models.api_v1_secret_approvals_post200_response_approval import ApiV1SecretApprovalsPost200ResponseApproval
from infisicalapi_client.models.api_v1_secret_approvals_post_request import ApiV1SecretApprovalsPostRequest
from infisicalapi_client.models.api_v1_secret_approvals_sap_id_patch_request import ApiV1SecretApprovalsSapIdPatchRequest
from infisicalapi_client.models.api_v1_secret_imports_get200_response import ApiV1SecretImportsGet200Response
from infisicalapi_client.models.api_v1_secret_imports_get200_response_secret_imports_inner import ApiV1SecretImportsGet200ResponseSecretImportsInner
from infisicalapi_client.models.api_v1_secret_imports_get200_response_secret_imports_inner_import_env import ApiV1SecretImportsGet200ResponseSecretImportsInnerImportEnv
from infisicalapi_client.models.api_v1_secret_imports_post200_response import ApiV1SecretImportsPost200Response
from infisicalapi_client.models.api_v1_secret_imports_post_request import ApiV1SecretImportsPostRequest
from infisicalapi_client.models.api_v1_secret_imports_post_request_import import ApiV1SecretImportsPostRequestImport
from infisicalapi_client.models.api_v1_secret_imports_secret_import_id_delete_request import ApiV1SecretImportsSecretImportIdDeleteRequest
from infisicalapi_client.models.api_v1_secret_imports_secret_import_id_patch_request import ApiV1SecretImportsSecretImportIdPatchRequest
from infisicalapi_client.models.api_v1_secret_imports_secret_import_id_patch_request_import import ApiV1SecretImportsSecretImportIdPatchRequestImport
from infisicalapi_client.models.api_v1_secret_imports_secret_import_id_replication_resync_post_request import ApiV1SecretImportsSecretImportIdReplicationResyncPostRequest
from infisicalapi_client.models.api_v1_secret_imports_secrets_get200_response import ApiV1SecretImportsSecretsGet200Response
from infisicalapi_client.models.api_v1_secret_imports_secrets_get200_response_secrets_inner import ApiV1SecretImportsSecretsGet200ResponseSecretsInner
from infisicalapi_client.models.api_v1_secret_imports_secrets_get200_response_secrets_inner_secrets_inner import ApiV1SecretImportsSecretsGet200ResponseSecretsInnerSecretsInner
from infisicalapi_client.models.api_v1_secret_imports_secrets_raw_get200_response import ApiV1SecretImportsSecretsRawGet200Response
from infisicalapi_client.models.api_v1_secret_imports_secrets_raw_get200_response_secrets_inner import ApiV1SecretImportsSecretsRawGet200ResponseSecretsInner
from infisicalapi_client.models.api_v1_secret_rotation_providers_workspace_id_get200_response import ApiV1SecretRotationProvidersWorkspaceIdGet200Response
from infisicalapi_client.models.api_v1_secret_rotation_providers_workspace_id_get200_response_providers_inner import ApiV1SecretRotationProvidersWorkspaceIdGet200ResponseProvidersInner
from infisicalapi_client.models.api_v1_secret_rotations_get200_response import ApiV1SecretRotationsGet200Response
from infisicalapi_client.models.api_v1_secret_rotations_get200_response_secret_rotations_inner import ApiV1SecretRotationsGet200ResponseSecretRotationsInner
from infisicalapi_client.models.api_v1_secret_rotations_get200_response_secret_rotations_inner_outputs_inner import ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner
from infisicalapi_client.models.api_v1_secret_rotations_get200_response_secret_rotations_inner_outputs_inner_secret import ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInnerSecret
from infisicalapi_client.models.api_v1_secret_rotations_post200_response import ApiV1SecretRotationsPost200Response
from infisicalapi_client.models.api_v1_secret_rotations_post200_response_secret_rotation import ApiV1SecretRotationsPost200ResponseSecretRotation
from infisicalapi_client.models.api_v1_secret_rotations_post200_response_secret_rotation_outputs_inner import ApiV1SecretRotationsPost200ResponseSecretRotationOutputsInner
from infisicalapi_client.models.api_v1_secret_rotations_post_request import ApiV1SecretRotationsPostRequest
from infisicalapi_client.models.api_v1_secret_rotations_restart_post200_response import ApiV1SecretRotationsRestartPost200Response
from infisicalapi_client.models.api_v1_secret_rotations_restart_post200_response_secret_rotation import ApiV1SecretRotationsRestartPost200ResponseSecretRotation
from infisicalapi_client.models.api_v1_secret_rotations_restart_post_request import ApiV1SecretRotationsRestartPostRequest
from infisicalapi_client.models.api_v1_secret_scanning_create_installation_session_organization_post200_response import ApiV1SecretScanningCreateInstallationSessionOrganizationPost200Response
from infisicalapi_client.models.api_v1_secret_scanning_create_installation_session_organization_post_request import ApiV1SecretScanningCreateInstallationSessionOrganizationPostRequest
from infisicalapi_client.models.api_v1_secret_scanning_installation_status_organization_organization_id_get200_response import ApiV1SecretScanningInstallationStatusOrganizationOrganizationIdGet200Response
from infisicalapi_client.models.api_v1_secret_scanning_link_installation_post200_response import ApiV1SecretScanningLinkInstallationPost200Response
from infisicalapi_client.models.api_v1_secret_scanning_link_installation_post_request import ApiV1SecretScanningLinkInstallationPostRequest
from infisicalapi_client.models.api_v1_secret_scanning_organization_organization_id_risks_get200_response import ApiV1SecretScanningOrganizationOrganizationIdRisksGet200Response
from infisicalapi_client.models.api_v1_secret_scanning_organization_organization_id_risks_get200_response_risks_inner import ApiV1SecretScanningOrganizationOrganizationIdRisksGet200ResponseRisksInner
from infisicalapi_client.models.api_v1_secret_scanning_organization_organization_id_risks_risk_id_status_post_request import ApiV1SecretScanningOrganizationOrganizationIdRisksRiskIdStatusPostRequest
from infisicalapi_client.models.api_v1_secret_secret_id_secret_versions_get200_response import ApiV1SecretSecretIdSecretVersionsGet200Response
from infisicalapi_client.models.api_v1_secret_secret_id_secret_versions_get200_response_secret_versions_inner import ApiV1SecretSecretIdSecretVersionsGet200ResponseSecretVersionsInner
from infisicalapi_client.models.api_v1_secret_sharing_get200_response import ApiV1SecretSharingGet200Response
from infisicalapi_client.models.api_v1_secret_sharing_get200_response_secrets_inner import ApiV1SecretSharingGet200ResponseSecretsInner
from infisicalapi_client.models.api_v1_secret_sharing_post200_response import ApiV1SecretSharingPost200Response
from infisicalapi_client.models.api_v1_secret_sharing_post_request import ApiV1SecretSharingPostRequest
from infisicalapi_client.models.api_v1_secret_sharing_public_id_get200_response import ApiV1SecretSharingPublicIdGet200Response
from infisicalapi_client.models.api_v1_secret_sharing_public_post_request import ApiV1SecretSharingPublicPostRequest
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response import ApiV1SecretSnapshotSecretSnapshotIdGet200Response
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshot
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_environment import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotEnvironment
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_folder_version_inner import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotFolderVersionInner
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_secret_versions_inner import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInner
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_get200_response_secret_snapshot_secret_versions_inner_tags_inner import ApiV1SecretSnapshotSecretSnapshotIdGet200ResponseSecretSnapshotSecretVersionsInnerTagsInner
from infisicalapi_client.models.api_v1_secret_snapshot_secret_snapshot_id_rollback_post200_response import ApiV1SecretSnapshotSecretSnapshotIdRollbackPost200Response
from infisicalapi_client.models.api_v1_sso_config_get200_response import ApiV1SsoConfigGet200Response
from infisicalapi_client.models.api_v1_sso_config_patch_request import ApiV1SsoConfigPatchRequest
from infisicalapi_client.models.api_v1_sso_config_post200_response import ApiV1SsoConfigPost200Response
from infisicalapi_client.models.api_v1_sso_config_post_request import ApiV1SsoConfigPostRequest
from infisicalapi_client.models.api_v1_sso_oidc_config_get200_response import ApiV1SsoOidcConfigGet200Response
from infisicalapi_client.models.api_v1_sso_oidc_config_patch200_response import ApiV1SsoOidcConfigPatch200Response
from infisicalapi_client.models.api_v1_sso_oidc_config_patch_request import ApiV1SsoOidcConfigPatchRequest
from infisicalapi_client.models.api_v1_sso_oidc_config_post200_response import ApiV1SsoOidcConfigPost200Response
from infisicalapi_client.models.api_v1_sso_oidc_config_post_request import ApiV1SsoOidcConfigPostRequest
from infisicalapi_client.models.api_v1_sso_token_exchange_post_request import ApiV1SsoTokenExchangePostRequest
from infisicalapi_client.models.api_v1_user_action_get200_response import ApiV1UserActionGet200Response
from infisicalapi_client.models.api_v1_user_action_get200_response_user_action import ApiV1UserActionGet200ResponseUserAction
from infisicalapi_client.models.api_v1_user_action_post200_response import ApiV1UserActionPost200Response
from infisicalapi_client.models.api_v1_user_action_post200_response_user_action import ApiV1UserActionPost200ResponseUserAction
from infisicalapi_client.models.api_v1_user_action_post_request import ApiV1UserActionPostRequest
from infisicalapi_client.models.api_v1_user_engagement_me_wish_post_request import ApiV1UserEngagementMeWishPostRequest
from infisicalapi_client.models.api_v1_user_get200_response import ApiV1UserGet200Response
from infisicalapi_client.models.api_v1_user_get200_response_user import ApiV1UserGet200ResponseUser
from infisicalapi_client.models.api_v1_user_me_project_favorites_get200_response import ApiV1UserMeProjectFavoritesGet200Response
from infisicalapi_client.models.api_v1_user_me_project_favorites_put_request import ApiV1UserMeProjectFavoritesPutRequest
from infisicalapi_client.models.api_v1_user_private_key_get200_response import ApiV1UserPrivateKeyGet200Response
from infisicalapi_client.models.api_v1_webhooks_get200_response import ApiV1WebhooksGet200Response
from infisicalapi_client.models.api_v1_webhooks_get200_response_webhooks_inner import ApiV1WebhooksGet200ResponseWebhooksInner
from infisicalapi_client.models.api_v1_webhooks_post200_response import ApiV1WebhooksPost200Response
from infisicalapi_client.models.api_v1_webhooks_post200_response_webhook import ApiV1WebhooksPost200ResponseWebhook
from infisicalapi_client.models.api_v1_webhooks_post_request import ApiV1WebhooksPostRequest
from infisicalapi_client.models.api_v1_webhooks_webhook_id_patch_request import ApiV1WebhooksWebhookIdPatchRequest
from infisicalapi_client.models.api_v1_workspace_get200_response import ApiV1WorkspaceGet200Response
from infisicalapi_client.models.api_v1_workspace_get200_response_workspaces_inner import ApiV1WorkspaceGet200ResponseWorkspacesInner
from infisicalapi_client.models.api_v1_workspace_project_id_permissions_get200_response import ApiV1WorkspaceProjectIdPermissionsGet200Response
from infisicalapi_client.models.api_v1_workspace_project_id_permissions_get200_response_data import ApiV1WorkspaceProjectIdPermissionsGet200ResponseData
from infisicalapi_client.models.api_v1_workspace_project_id_permissions_get200_response_data_membership import ApiV1WorkspaceProjectIdPermissionsGet200ResponseDataMembership
from infisicalapi_client.models.api_v1_workspace_project_id_permissions_get200_response_data_membership_roles_inner import ApiV1WorkspaceProjectIdPermissionsGet200ResponseDataMembershipRolesInner
from infisicalapi_client.models.api_v1_workspace_project_id_tags_get200_response import ApiV1WorkspaceProjectIdTagsGet200Response
from infisicalapi_client.models.api_v1_workspace_project_id_tags_get200_response_workspace_tags_inner import ApiV1WorkspaceProjectIdTagsGet200ResponseWorkspaceTagsInner
from infisicalapi_client.models.api_v1_workspace_project_id_tags_post200_response import ApiV1WorkspaceProjectIdTagsPost200Response
from infisicalapi_client.models.api_v1_workspace_project_id_tags_post_request import ApiV1WorkspaceProjectIdTagsPostRequest
from infisicalapi_client.models.api_v1_workspace_project_id_tags_tag_id_get200_response import ApiV1WorkspaceProjectIdTagsTagIdGet200Response
from infisicalapi_client.models.api_v1_workspace_project_id_tags_tag_id_get200_response_workspace_tag import ApiV1WorkspaceProjectIdTagsTagIdGet200ResponseWorkspaceTag
from infisicalapi_client.models.api_v1_workspace_project_id_tags_tag_id_patch_request import ApiV1WorkspaceProjectIdTagsTagIdPatchRequest
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_get200_response import ApiV1WorkspaceProjectSlugRolesGet200Response
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_get200_response_roles_inner import ApiV1WorkspaceProjectSlugRolesGet200ResponseRolesInner
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post200_response import ApiV1WorkspaceProjectSlugRolesPost200Response
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post200_response_role import ApiV1WorkspaceProjectSlugRolesPost200ResponseRole
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post200_response_role_permissions_inner import ApiV1WorkspaceProjectSlugRolesPost200ResponseRolePermissionsInner
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post200_response_role_permissions_inner_conditions import ApiV1WorkspaceProjectSlugRolesPost200ResponseRolePermissionsInnerConditions
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post200_response_role_permissions_inner_conditions_secret_path import ApiV1WorkspaceProjectSlugRolesPost200ResponseRolePermissionsInnerConditionsSecretPath
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post200_response_role_permissions_inner_subject import ApiV1WorkspaceProjectSlugRolesPost200ResponseRolePermissionsInnerSubject
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post_request import ApiV1WorkspaceProjectSlugRolesPostRequest
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post_request_permissions_inner import ApiV1WorkspaceProjectSlugRolesPostRequestPermissionsInner
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post_request_permissions_inner_conditions import ApiV1WorkspaceProjectSlugRolesPostRequestPermissionsInnerConditions
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_post_request_permissions_inner_conditions_secret_path import ApiV1WorkspaceProjectSlugRolesPostRequestPermissionsInnerConditionsSecretPath
from infisicalapi_client.models.api_v1_workspace_project_slug_roles_role_id_patch_request import ApiV1WorkspaceProjectSlugRolesRoleIdPatchRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_audit_logs_filters_actors_get200_response import ApiV1WorkspaceWorkspaceIdAuditLogsFiltersActorsGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_audit_logs_get200_response import ApiV1WorkspaceWorkspaceIdAuditLogsGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_audit_logs_get200_response_audit_logs_inner import ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_audit_logs_get200_response_audit_logs_inner_event import ApiV1WorkspaceWorkspaceIdAuditLogsGet200ResponseAuditLogsInnerEvent
from infisicalapi_client.models.api_v1_workspace_workspace_id_authorizations_get200_response import ApiV1WorkspaceWorkspaceIdAuthorizationsGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_authorizations_get200_response_authorizations_inner import ApiV1WorkspaceWorkspaceIdAuthorizationsGet200ResponseAuthorizationsInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_auto_capitalization_post_request import ApiV1WorkspaceWorkspaceIdAutoCapitalizationPostRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_delete200_response import ApiV1WorkspaceWorkspaceIdDelete200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_environments_env_id_get200_response import ApiV1WorkspaceWorkspaceIdEnvironmentsEnvIdGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_environments_env_id_get200_response_environment import ApiV1WorkspaceWorkspaceIdEnvironmentsEnvIdGet200ResponseEnvironment
from infisicalapi_client.models.api_v1_workspace_workspace_id_environments_id_patch_request import ApiV1WorkspaceWorkspaceIdEnvironmentsIdPatchRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_environments_post200_response import ApiV1WorkspaceWorkspaceIdEnvironmentsPost200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_environments_post_request import ApiV1WorkspaceWorkspaceIdEnvironmentsPostRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_get200_response import ApiV1WorkspaceWorkspaceIdGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_integrations_get200_response import ApiV1WorkspaceWorkspaceIdIntegrationsGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_integrations_get200_response_integrations_inner import ApiV1WorkspaceWorkspaceIdIntegrationsGet200ResponseIntegrationsInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_key_post_request import ApiV1WorkspaceWorkspaceIdKeyPostRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_key_post_request_key import ApiV1WorkspaceWorkspaceIdKeyPostRequestKey
from infisicalapi_client.models.api_v1_workspace_workspace_id_keys_get200_response import ApiV1WorkspaceWorkspaceIdKeysGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_keys_get200_response_public_keys_inner import ApiV1WorkspaceWorkspaceIdKeysGet200ResponsePublicKeysInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_kms_backup_get200_response import ApiV1WorkspaceWorkspaceIdKmsBackupGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_kms_backup_post_request import ApiV1WorkspaceWorkspaceIdKmsBackupPostRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_kms_get200_response import ApiV1WorkspaceWorkspaceIdKmsGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_kms_get200_response_secret_manager_kms_key import ApiV1WorkspaceWorkspaceIdKmsGet200ResponseSecretManagerKmsKey
from infisicalapi_client.models.api_v1_workspace_workspace_id_kms_patch_request import ApiV1WorkspaceWorkspaceIdKmsPatchRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_kms_patch_request_kms import ApiV1WorkspaceWorkspaceIdKmsPatchRequestKms
from infisicalapi_client.models.api_v1_workspace_workspace_id_kms_patch_request_kms_any_of import ApiV1WorkspaceWorkspaceIdKmsPatchRequestKmsAnyOf
from infisicalapi_client.models.api_v1_workspace_workspace_id_kms_patch_request_kms_any_of1 import ApiV1WorkspaceWorkspaceIdKmsPatchRequestKmsAnyOf1
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_details_post200_response import ApiV1WorkspaceWorkspaceIdMembershipsDetailsPost200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_details_post_request import ApiV1WorkspaceWorkspaceIdMembershipsDetailsPostRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_get200_response import ApiV1WorkspaceWorkspaceIdMembershipsGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_get200_response_memberships_inner import ApiV1WorkspaceWorkspaceIdMembershipsGet200ResponseMembershipsInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_get200_response_memberships_inner_user import ApiV1WorkspaceWorkspaceIdMembershipsGet200ResponseMembershipsInnerUser
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_membership_id_patch200_response import ApiV1WorkspaceWorkspaceIdMembershipsMembershipIdPatch200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_membership_id_patch200_response_roles_inner import ApiV1WorkspaceWorkspaceIdMembershipsMembershipIdPatch200ResponseRolesInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_membership_id_patch_request import ApiV1WorkspaceWorkspaceIdMembershipsMembershipIdPatchRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_membership_id_patch_request_roles_inner import ApiV1WorkspaceWorkspaceIdMembershipsMembershipIdPatchRequestRolesInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_membership_id_patch_request_roles_inner_any_of import ApiV1WorkspaceWorkspaceIdMembershipsMembershipIdPatchRequestRolesInnerAnyOf
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_membership_id_patch_request_roles_inner_any_of1 import ApiV1WorkspaceWorkspaceIdMembershipsMembershipIdPatchRequestRolesInnerAnyOf1
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_post200_response import ApiV1WorkspaceWorkspaceIdMembershipsPost200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_post_request import ApiV1WorkspaceWorkspaceIdMembershipsPostRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_memberships_post_request_members_inner import ApiV1WorkspaceWorkspaceIdMembershipsPostRequestMembersInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_migrate_v3_post200_response import ApiV1WorkspaceWorkspaceIdMigrateV3Post200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_name_post200_response import ApiV1WorkspaceWorkspaceIdNamePost200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_name_post_request import ApiV1WorkspaceWorkspaceIdNamePostRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_patch200_response import ApiV1WorkspaceWorkspaceIdPatch200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_patch_request import ApiV1WorkspaceWorkspaceIdPatchRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_secret_snapshots_count_get200_response import ApiV1WorkspaceWorkspaceIdSecretSnapshotsCountGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_secret_snapshots_get200_response import ApiV1WorkspaceWorkspaceIdSecretSnapshotsGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_secret_snapshots_get200_response_secret_snapshots_inner import ApiV1WorkspaceWorkspaceIdSecretSnapshotsGet200ResponseSecretSnapshotsInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_service_token_data_get200_response import ApiV1WorkspaceWorkspaceIdServiceTokenDataGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_service_token_data_get200_response_service_token_data_inner import ApiV1WorkspaceWorkspaceIdServiceTokenDataGet200ResponseServiceTokenDataInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_trusted_ips_get200_response import ApiV1WorkspaceWorkspaceIdTrustedIpsGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_trusted_ips_get200_response_trusted_ips_inner import ApiV1WorkspaceWorkspaceIdTrustedIpsGet200ResponseTrustedIpsInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_trusted_ips_post200_response import ApiV1WorkspaceWorkspaceIdTrustedIpsPost200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_trusted_ips_post_request import ApiV1WorkspaceWorkspaceIdTrustedIpsPostRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_trusted_ips_trusted_ip_id_patch_request import ApiV1WorkspaceWorkspaceIdTrustedIpsTrustedIpIdPatchRequest
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response import ApiV1WorkspaceWorkspaceIdUsersGet200Response
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner_project import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerProject
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner_roles_inner import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerRolesInner
from infisicalapi_client.models.api_v1_workspace_workspace_id_users_get200_response_users_inner_user import ApiV1WorkspaceWorkspaceIdUsersGet200ResponseUsersInnerUser
from infisicalapi_client.models.api_v1_workspace_workspace_slug_audit_logs_retention_put_request import ApiV1WorkspaceWorkspaceSlugAuditLogsRetentionPutRequest
from infisicalapi_client.models.api_v1_workspace_workspace_slug_version_limit_put_request import ApiV1WorkspaceWorkspaceSlugVersionLimitPutRequest
from infisicalapi_client.models.api_v2_auth_mfa_verify_post200_response import ApiV2AuthMfaVerifyPost200Response
from infisicalapi_client.models.api_v2_auth_mfa_verify_post_request import ApiV2AuthMfaVerifyPostRequest
from infisicalapi_client.models.api_v2_organizations_org_id_identity_memberships_get200_response import ApiV2OrganizationsOrgIdIdentityMembershipsGet200Response
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_get200_response import ApiV2OrganizationsOrganizationIdMembershipsGet200Response
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_get200_response_users_inner import ApiV2OrganizationsOrganizationIdMembershipsGet200ResponseUsersInner
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_get200_response_users_inner_user import ApiV2OrganizationsOrganizationIdMembershipsGet200ResponseUsersInnerUser
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_membership_id_delete200_response import ApiV2OrganizationsOrganizationIdMembershipsMembershipIdDelete200Response
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_membership_id_get200_response import ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200Response
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_membership_id_get200_response_membership import ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200ResponseMembership
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_membership_id_get200_response_membership_user import ApiV2OrganizationsOrganizationIdMembershipsMembershipIdGet200ResponseMembershipUser
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_membership_id_patch_request import ApiV2OrganizationsOrganizationIdMembershipsMembershipIdPatchRequest
from infisicalapi_client.models.api_v2_organizations_organization_id_memberships_membership_id_project_memberships_get200_response import ApiV2OrganizationsOrganizationIdMembershipsMembershipIdProjectMembershipsGet200Response
from infisicalapi_client.models.api_v2_organizations_organization_id_workspaces_get200_response import ApiV2OrganizationsOrganizationIdWorkspacesGet200Response
from infisicalapi_client.models.api_v2_organizations_organization_id_workspaces_get200_response_workspaces_inner import ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInner
from infisicalapi_client.models.api_v2_organizations_organization_id_workspaces_get200_response_workspaces_inner_environments_inner import ApiV2OrganizationsOrganizationIdWorkspacesGet200ResponseWorkspacesInnerEnvironmentsInner
from infisicalapi_client.models.api_v2_service_token_get200_response import ApiV2ServiceTokenGet200Response
from infisicalapi_client.models.api_v2_service_token_get200_response_user import ApiV2ServiceTokenGet200ResponseUser
from infisicalapi_client.models.api_v2_service_token_post200_response import ApiV2ServiceTokenPost200Response
from infisicalapi_client.models.api_v2_service_token_post_request import ApiV2ServiceTokenPostRequest
from infisicalapi_client.models.api_v2_service_token_post_request_scopes_inner import ApiV2ServiceTokenPostRequestScopesInner
from infisicalapi_client.models.api_v2_service_token_service_token_id_delete200_response import ApiV2ServiceTokenServiceTokenIdDelete200Response
from infisicalapi_client.models.api_v2_users_me_api_keys_api_key_data_id_delete200_response import ApiV2UsersMeApiKeysApiKeyDataIdDelete200Response
from infisicalapi_client.models.api_v2_users_me_api_keys_get200_response_inner import ApiV2UsersMeApiKeysGet200ResponseInner
from infisicalapi_client.models.api_v2_users_me_api_keys_post200_response import ApiV2UsersMeApiKeysPost200Response
from infisicalapi_client.models.api_v2_users_me_api_keys_post_request import ApiV2UsersMeApiKeysPostRequest
from infisicalapi_client.models.api_v2_users_me_auth_methods_put_request import ApiV2UsersMeAuthMethodsPutRequest
from infisicalapi_client.models.api_v2_users_me_emails_code_post_request import ApiV2UsersMeEmailsCodePostRequest
from infisicalapi_client.models.api_v2_users_me_emails_verify_post_request import ApiV2UsersMeEmailsVerifyPostRequest
from infisicalapi_client.models.api_v2_users_me_mfa_patch200_response import ApiV2UsersMeMfaPatch200Response
from infisicalapi_client.models.api_v2_users_me_mfa_patch_request import ApiV2UsersMeMfaPatchRequest
from infisicalapi_client.models.api_v2_users_me_name_patch_request import ApiV2UsersMeNamePatchRequest
from infisicalapi_client.models.api_v2_users_me_sessions_get200_response_inner import ApiV2UsersMeSessionsGet200ResponseInner
from infisicalapi_client.models.api_v2_workspace_post200_response import ApiV2WorkspacePost200Response
from infisicalapi_client.models.api_v2_workspace_post_request import ApiV2WorkspacePostRequest
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_get200_response import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdGet200Response
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_patch_request import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequest
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_patch_request_roles_inner import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInner
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_patch_request_roles_inner_any_of import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_patch_request_roles_inner_any_of1 import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPatchRequestRolesInnerAnyOf1
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_post200_response import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPost200Response
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_post200_response_identity_membership import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPost200ResponseIdentityMembership
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_post_request import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPostRequest
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_post_request_roles_inner import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPostRequestRolesInner
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_post_request_roles_inner_any_of import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPostRequestRolesInnerAnyOf
from infisicalapi_client.models.api_v2_workspace_project_id_identity_memberships_identity_id_post_request_roles_inner_any_of1 import ApiV2WorkspaceProjectIdIdentityMembershipsIdentityIdPostRequestRolesInnerAnyOf1
from infisicalapi_client.models.api_v2_workspace_project_id_memberships_delete_request import ApiV2WorkspaceProjectIdMembershipsDeleteRequest
from infisicalapi_client.models.api_v2_workspace_project_id_memberships_post200_response import ApiV2WorkspaceProjectIdMembershipsPost200Response
from infisicalapi_client.models.api_v2_workspace_project_id_memberships_post_request import ApiV2WorkspaceProjectIdMembershipsPostRequest
from infisicalapi_client.models.api_v2_workspace_project_id_upgrade_post_request import ApiV2WorkspaceProjectIdUpgradePostRequest
from infisicalapi_client.models.api_v2_workspace_project_id_upgrade_status_get200_response import ApiV2WorkspaceProjectIdUpgradeStatusGet200Response
from infisicalapi_client.models.api_v2_workspace_project_slug_groups_get200_response import ApiV2WorkspaceProjectSlugGroupsGet200Response
from infisicalapi_client.models.api_v2_workspace_project_slug_groups_get200_response_group_memberships_inner import ApiV2WorkspaceProjectSlugGroupsGet200ResponseGroupMembershipsInner
from infisicalapi_client.models.api_v2_workspace_project_slug_groups_get200_response_group_memberships_inner_group import ApiV2WorkspaceProjectSlugGroupsGet200ResponseGroupMembershipsInnerGroup
from infisicalapi_client.models.api_v2_workspace_project_slug_groups_group_slug_patch_request import ApiV2WorkspaceProjectSlugGroupsGroupSlugPatchRequest
from infisicalapi_client.models.api_v2_workspace_project_slug_groups_group_slug_post200_response import ApiV2WorkspaceProjectSlugGroupsGroupSlugPost200Response
from infisicalapi_client.models.api_v2_workspace_project_slug_groups_group_slug_post200_response_group_membership import ApiV2WorkspaceProjectSlugGroupsGroupSlugPost200ResponseGroupMembership
from infisicalapi_client.models.api_v2_workspace_project_slug_groups_group_slug_post_request import ApiV2WorkspaceProjectSlugGroupsGroupSlugPostRequest
from infisicalapi_client.models.api_v2_workspace_slug_cas_get200_response import ApiV2WorkspaceSlugCasGet200Response
from infisicalapi_client.models.api_v2_workspace_slug_certificates_get200_response import ApiV2WorkspaceSlugCertificatesGet200Response
from infisicalapi_client.models.api_v2_workspace_slug_patch_request import ApiV2WorkspaceSlugPatchRequest
from infisicalapi_client.models.api_v2_workspace_workspace_id_encrypted_key_get200_response import ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200Response
from infisicalapi_client.models.api_v2_workspace_workspace_id_encrypted_key_get200_response_sender import ApiV2WorkspaceWorkspaceIdEncryptedKeyGet200ResponseSender
from infisicalapi_client.models.api_v3_auth_login1_post_request import ApiV3AuthLogin1PostRequest
from infisicalapi_client.models.api_v3_auth_login2_post200_response import ApiV3AuthLogin2Post200Response
from infisicalapi_client.models.api_v3_auth_login2_post200_response_any_of import ApiV3AuthLogin2Post200ResponseAnyOf
from infisicalapi_client.models.api_v3_auth_login2_post200_response_any_of1 import ApiV3AuthLogin2Post200ResponseAnyOf1
from infisicalapi_client.models.api_v3_auth_login2_post_request import ApiV3AuthLogin2PostRequest
from infisicalapi_client.models.api_v3_secrets_backfill_secret_references_post_request import ApiV3SecretsBackfillSecretReferencesPostRequest
from infisicalapi_client.models.api_v3_secrets_batch_delete_request import ApiV3SecretsBatchDeleteRequest
from infisicalapi_client.models.api_v3_secrets_batch_delete_request_secrets_inner import ApiV3SecretsBatchDeleteRequestSecretsInner
from infisicalapi_client.models.api_v3_secrets_batch_patch_request import ApiV3SecretsBatchPatchRequest
from infisicalapi_client.models.api_v3_secrets_batch_patch_request_secrets_inner import ApiV3SecretsBatchPatchRequestSecretsInner
from infisicalapi_client.models.api_v3_secrets_batch_post200_response import ApiV3SecretsBatchPost200Response
from infisicalapi_client.models.api_v3_secrets_batch_post200_response_any_of import ApiV3SecretsBatchPost200ResponseAnyOf
from infisicalapi_client.models.api_v3_secrets_batch_post_request import ApiV3SecretsBatchPostRequest
from infisicalapi_client.models.api_v3_secrets_batch_post_request_secrets_inner import ApiV3SecretsBatchPostRequestSecretsInner
from infisicalapi_client.models.api_v3_secrets_batch_raw_delete_request import ApiV3SecretsBatchRawDeleteRequest
from infisicalapi_client.models.api_v3_secrets_batch_raw_delete_request_secrets_inner import ApiV3SecretsBatchRawDeleteRequestSecretsInner
from infisicalapi_client.models.api_v3_secrets_batch_raw_patch_request import ApiV3SecretsBatchRawPatchRequest
from infisicalapi_client.models.api_v3_secrets_batch_raw_patch_request_secrets_inner import ApiV3SecretsBatchRawPatchRequestSecretsInner
from infisicalapi_client.models.api_v3_secrets_batch_raw_post200_response import ApiV3SecretsBatchRawPost200Response
from infisicalapi_client.models.api_v3_secrets_batch_raw_post200_response_any_of import ApiV3SecretsBatchRawPost200ResponseAnyOf
from infisicalapi_client.models.api_v3_secrets_batch_raw_post_request import ApiV3SecretsBatchRawPostRequest
from infisicalapi_client.models.api_v3_secrets_batch_raw_post_request_secrets_inner import ApiV3SecretsBatchRawPostRequestSecretsInner
from infisicalapi_client.models.api_v3_secrets_get200_response import ApiV3SecretsGet200Response
from infisicalapi_client.models.api_v3_secrets_get200_response_imports_inner import ApiV3SecretsGet200ResponseImportsInner
from infisicalapi_client.models.api_v3_secrets_get200_response_imports_inner_secrets_inner import ApiV3SecretsGet200ResponseImportsInnerSecretsInner
from infisicalapi_client.models.api_v3_secrets_get200_response_secrets_inner import ApiV3SecretsGet200ResponseSecretsInner
from infisicalapi_client.models.api_v3_secrets_move_post200_response import ApiV3SecretsMovePost200Response
from infisicalapi_client.models.api_v3_secrets_move_post_request import ApiV3SecretsMovePostRequest
from infisicalapi_client.models.api_v3_secrets_raw_get200_response import ApiV3SecretsRawGet200Response
from infisicalapi_client.models.api_v3_secrets_raw_get200_response_imports_inner import ApiV3SecretsRawGet200ResponseImportsInner
from infisicalapi_client.models.api_v3_secrets_raw_get200_response_imports_inner_secrets_inner import ApiV3SecretsRawGet200ResponseImportsInnerSecretsInner
from infisicalapi_client.models.api_v3_secrets_raw_get200_response_secrets_inner import ApiV3SecretsRawGet200ResponseSecretsInner
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_delete_request import ApiV3SecretsRawSecretNameDeleteRequest
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_get200_response import ApiV3SecretsRawSecretNameGet200Response
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_get200_response_secret import ApiV3SecretsRawSecretNameGet200ResponseSecret
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_patch_request import ApiV3SecretsRawSecretNamePatchRequest
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_post200_response import ApiV3SecretsRawSecretNamePost200Response
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_post200_response_any_of import ApiV3SecretsRawSecretNamePost200ResponseAnyOf
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_post200_response_any_of1 import ApiV3SecretsRawSecretNamePost200ResponseAnyOf1
from infisicalapi_client.models.api_v3_secrets_raw_secret_name_post_request import ApiV3SecretsRawSecretNamePostRequest
from infisicalapi_client.models.api_v3_secrets_secret_name_delete_request import ApiV3SecretsSecretNameDeleteRequest
from infisicalapi_client.models.api_v3_secrets_secret_name_get200_response import ApiV3SecretsSecretNameGet200Response
from infisicalapi_client.models.api_v3_secrets_secret_name_get200_response_secret import ApiV3SecretsSecretNameGet200ResponseSecret
from infisicalapi_client.models.api_v3_secrets_secret_name_patch_request import ApiV3SecretsSecretNamePatchRequest
from infisicalapi_client.models.api_v3_secrets_secret_name_post200_response import ApiV3SecretsSecretNamePost200Response
from infisicalapi_client.models.api_v3_secrets_secret_name_post200_response_any_of import ApiV3SecretsSecretNamePost200ResponseAnyOf
from infisicalapi_client.models.api_v3_secrets_secret_name_post_request import ApiV3SecretsSecretNamePostRequest
from infisicalapi_client.models.api_v3_secrets_tags_secret_name_delete_request import ApiV3SecretsTagsSecretNameDeleteRequest
from infisicalapi_client.models.api_v3_secrets_tags_secret_name_post200_response import ApiV3SecretsTagsSecretNamePost200Response
from infisicalapi_client.models.api_v3_secrets_tags_secret_name_post200_response_secret import ApiV3SecretsTagsSecretNamePost200ResponseSecret
from infisicalapi_client.models.api_v3_secrets_tags_secret_name_post200_response_secret_tags_inner import ApiV3SecretsTagsSecretNamePost200ResponseSecretTagsInner
from infisicalapi_client.models.api_v3_secrets_tags_secret_name_post_request import ApiV3SecretsTagsSecretNamePostRequest
from infisicalapi_client.models.api_v3_signup_complete_account_signup_post200_response import ApiV3SignupCompleteAccountSignupPost200Response
from infisicalapi_client.models.api_v3_signup_complete_account_signup_post_request import ApiV3SignupCompleteAccountSignupPostRequest
from infisicalapi_client.models.api_v3_signup_email_verify_post200_response import ApiV3SignupEmailVerifyPost200Response
from infisicalapi_client.models.api_v3_users_me_api_keys_get200_response import ApiV3UsersMeApiKeysGet200Response
from infisicalapi_client.models.api_v3_workspaces_project_id_secrets_get200_response import ApiV3WorkspacesProjectIdSecretsGet200Response
from infisicalapi_client.models.api_v3_workspaces_project_id_secrets_get200_response_secrets_inner import ApiV3WorkspacesProjectIdSecretsGet200ResponseSecretsInner
from infisicalapi_client.models.api_v3_workspaces_project_id_secrets_names_post_request import ApiV3WorkspacesProjectIdSecretsNamesPostRequest
from infisicalapi_client.models.api_v3_workspaces_project_id_secrets_names_post_request_secrets_to_update_inner import ApiV3WorkspacesProjectIdSecretsNamesPostRequestSecretsToUpdateInner



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr

class ApiV3AuthLogin2Post200ResponseAnyOf1(BaseModel):
    """
    ApiV3AuthLogin2Post200ResponseAnyOf1
    """
    mfa_enabled: StrictBool = Field(default=..., alias="mfaEnabled")
    encryption_version: Optional[Union[StrictFloat, StrictInt]] = Field(default=1, alias="encryptionVersion")
    protected_key: Optional[StrictStr] = Field(default=..., alias="protectedKey")
    protected_key_iv: Optional[StrictStr] = Field(default=..., alias="protectedKeyIV")
    protected_key_tag: Optional[StrictStr] = Field(default=..., alias="protectedKeyTag")
    public_key: StrictStr = Field(default=..., alias="publicKey")
    encrypted_private_key: StrictStr = Field(default=..., alias="encryptedPrivateKey")
    iv: StrictStr = Field(...)
    tag: StrictStr = Field(...)
    token: StrictStr = Field(...)
    __properties = ["mfaEnabled", "encryptionVersion", "protectedKey", "protectedKeyIV", "protectedKeyTag", "publicKey", "encryptedPrivateKey", "iv", "tag", "token"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV3AuthLogin2Post200ResponseAnyOf1:
        """Create an instance of ApiV3AuthLogin2Post200ResponseAnyOf1 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # set to None if encryption_version (nullable) is None
        # and __fields_set__ contains the field
        if self.encryption_version is None and "encryption_version" in self.__fields_set__:
            _dict['encryptionVersion'] = None

        # set to None if protected_key (nullable) is None
        # and __fields_set__ contains the field
        if self.protected_key is None and "protected_key" in self.__fields_set__:
            _dict['protectedKey'] = None

        # set to None if protected_key_iv (nullable) is None
        # and __fields_set__ contains the field
        if self.protected_key_iv is None and "protected_key_iv" in self.__fields_set__:
            _dict['protectedKeyIV'] = None

        # set to None if protected_key_tag (nullable) is None
        # and __fields_set__ contains the field
        if self.protected_key_tag is None and "protected_key_tag" in self.__fields_set__:
            _dict['protectedKeyTag'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV3AuthLogin2Post200ResponseAnyOf1:
        """Create an instance of ApiV3AuthLogin2Post200ResponseAnyOf1 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV3AuthLogin2Post200ResponseAnyOf1.parse_obj(obj)

        _obj = ApiV3AuthLogin2Post200ResponseAnyOf1.parse_obj({
            "mfa_enabled": obj.get("mfaEnabled"),
            "encryption_version": obj.get("encryptionVersion") if obj.get("encryptionVersion") is not None else 1,
            "protected_key": obj.get("protectedKey"),
            "protected_key_iv": obj.get("protectedKeyIV"),
            "protected_key_tag": obj.get("protectedKeyTag"),
            "public_key": obj.get("publicKey"),
            "encrypted_private_key": obj.get("encryptedPrivateKey"),
            "iv": obj.get("iv"),
            "tag": obj.get("tag"),
            "token": obj.get("token")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist
from infisicalapi_client.models.api_v1_secret_approvals_get200_response_approvals_inner_environment import ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment
from infisicalapi_client.models.api_v1_secret_rotations_get200_response_secret_rotations_inner_outputs_inner import ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner

class ApiV1SecretRotationsGet200ResponseSecretRotationsInner(BaseModel):
    """
    ApiV1SecretRotationsGet200ResponseSecretRotationsInner
    """
    id: StrictStr = Field(...)
    provider: StrictStr = Field(...)
    secret_path: StrictStr = Field(default=..., alias="secretPath")
    interval: Union[StrictFloat, StrictInt] = Field(...)
    last_rotated_at: Optional[datetime] = Field(default=None, alias="lastRotatedAt")
    status: Optional[StrictStr] = None
    status_message: Optional[StrictStr] = Field(default=None, alias="statusMessage")
    encrypted_data: Optional[StrictStr] = Field(default=None, alias="encryptedData")
    encrypted_data_iv: Optional[StrictStr] = Field(default=None, alias="encryptedDataIV")
    encrypted_data_tag: Optional[StrictStr] = Field(default=None, alias="encryptedDataTag")
    algorithm: Optional[StrictStr] = None
    key_encoding: Optional[StrictStr] = Field(default=None, alias="keyEncoding")
    env_id: StrictStr = Field(default=..., alias="envId")
    created_at: datetime = Field(default=..., alias="createdAt")
    updated_at: datetime = Field(default=..., alias="updatedAt")
    environment: ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment = Field(...)
    outputs: conlist(ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner) = Field(...)
    __properties = ["id", "provider", "secretPath", "interval", "lastRotatedAt", "status", "statusMessage", "encryptedData", "encryptedDataIV", "encryptedDataTag", "algorithm", "keyEncoding", "envId", "createdAt", "updatedAt", "environment", "outputs"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1SecretRotationsGet200ResponseSecretRotationsInner:
        """Create an instance of ApiV1SecretRotationsGet200ResponseSecretRotationsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of environment
        if self.environment:
            _dict['environment'] = self.environment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in outputs (list)
        _items = []
        if self.outputs:
            for _item in self.outputs:
                if _item:
                    _items.append(_item.to_dict())
            _dict['outputs'] = _items
        # set to None if last_rotated_at (nullable) is None
        # and __fields_set__ contains the field
        if self.last_rotated_at is None and "last_rotated_at" in self.__fields_set__:
            _dict['lastRotatedAt'] = None

        # set to None if status (nullable) is None
        # and __fields_set__ contains the field
        if self.status is None and "status" in self.__fields_set__:
            _dict['status'] = None

        # set to None if status_message (nullable) is None
        # and __fields_set__ contains the field
        if self.status_message is None and "status_message" in self.__fields_set__:
            _dict['statusMessage'] = None

        # set to None if encrypted_data (nullable) is None
        # and __fields_set__ contains the field
        if self.encrypted_data is None and "encrypted_data" in self.__fields_set__:
            _dict['encryptedData'] = None

        # set to None if encrypted_data_iv (nullable) is None
        # and __fields_set__ contains the field
        if self.encrypted_data_iv is None and "encrypted_data_iv" in self.__fields_set__:
            _dict['encryptedDataIV'] = None

        # set to None if encrypted_data_tag (nullable) is None
        # and __fields_set__ contains the field
        if self.encrypted_data_tag is None and "encrypted_data_tag" in self.__fields_set__:
            _dict['encryptedDataTag'] = None

        # set to None if algorithm (nullable) is None
        # and __fields_set__ contains the field
        if self.algorithm is None and "algorithm" in self.__fields_set__:
            _dict['algorithm'] = None

        # set to None if key_encoding (nullable) is None
        # and __fields_set__ contains the field
        if self.key_encoding is None and "key_encoding" in self.__fields_set__:
            _dict['keyEncoding'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1SecretRotationsGet200ResponseSecretRotationsInner:
        """Create an instance of ApiV1SecretRotationsGet200ResponseSecretRotationsInner from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1SecretRotationsGet200ResponseSecretRotationsInner.parse_obj(obj)

        _obj = ApiV1SecretRotationsGet200ResponseSecretRotationsInner.parse_obj({
            "id": obj.get("id"),
            "provider": obj.get("provider"),
            "secret_path": obj.get("secretPath"),
            "interval": obj.get("interval"),
            "last_rotated_at": obj.get("lastRotatedAt"),
            "status": obj.get("status"),
            "status_message": obj.get("statusMessage"),
            "encrypted_data": obj.get("encryptedData"),
            "encrypted_data_iv": obj.get("encryptedDataIV"),
            "encrypted_data_tag": obj.get("encryptedDataTag"),
            "algorithm": obj.get("algorithm"),
            "key_encoding": obj.get("keyEncoding"),
            "env_id": obj.get("envId"),
            "created_at": obj.get("createdAt"),
            "updated_at": obj.get("updatedAt"),
            "environment": ApiV1SecretApprovalsGet200ResponseApprovalsInnerEnvironment.from_dict(obj.get("environment")) if obj.get("environment") is not None else None,
            "outputs": [ApiV1SecretRotationsGet200ResponseSecretRotationsInnerOutputsInner.from_dict(_item) for _item in obj.get("outputs")] if obj.get("outputs") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_pki_ca_ca_id_issue_certificate_post200_response import ApiV1PkiCaCaIdIssueCertificatePost200Response  # noqa: E501

class TestApiV1PkiCaCaIdIssueCertificatePost200Response(unittest.TestCase):
    """ApiV1PkiCaCaIdIssueCertificatePost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1PkiCaCaIdIssueCertificatePost200Response:
        """Test ApiV1PkiCaCaIdIssueCertificatePost200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1PkiCaCaIdIssueCertificatePost200Response`
        """
        model = ApiV1PkiCaCaIdIssueCertificatePost200Response()  # noqa: E501
        if include_optional:
            return ApiV1PkiCaCaIdIssueCertificatePost200Response(
                certificate = '',
                issuing_ca_certificate = '',
                certificate_chain = '',
                private_key = '',
                serial_number = ''
            )
        else:
            return ApiV1PkiCaCaIdIssueCertificatePost200Response(
                certificate = '',
                issuing_ca_certificate = '',
                certificate_chain = '',
                private_key = '',
                serial_number = '',
        )
        """

    def testApiV1PkiCaCaIdIssueCertificatePost200Response(self):
        """Test ApiV1PkiCaCaIdIssueCertificatePost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v2_workspace_slug_certificates_get200_response import ApiV2WorkspaceSlugCertificatesGet200Response  # noqa: E501

class TestApiV2WorkspaceSlugCertificatesGet200Response(unittest.TestCase):
    """ApiV2WorkspaceSlugCertificatesGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV2WorkspaceSlugCertificatesGet200Response:
        """Test ApiV2WorkspaceSlugCertificatesGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV2WorkspaceSlugCertificatesGet200Response`
        """
        model = ApiV2WorkspaceSlugCertificatesGet200Response()  # noqa: E501
        if include_optional:
            return ApiV2WorkspaceSlugCertificatesGet200Response(
                certificates = [
                    infisicalapi_client.models._api_v1_pki_certificates__serial_number__get_200_response_certificate._api_v1_pki_certificates__serialNumber__get_200_response_certificate(
                        id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        ca_id = '', 
                        status = '', 
                        serial_number = '', 
                        friendly_name = '', 
                        common_name = '', 
                        not_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        not_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        revoked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        revocation_reason = 1.337, 
                        alt_names = '', )
                    ],
                total_count = 1.337
            )
        else:
            return ApiV2WorkspaceSlugCertificatesGet200Response(
                certificates = [
                    infisicalapi_client.models._api_v1_pki_certificates__serial_number__get_200_response_certificate._api_v1_pki_certificates__serialNumber__get_200_response_certificate(
                        id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        ca_id = '', 
                        status = '', 
                        serial_number = '', 
                        friendly_name = '', 
                        common_name = '', 
                        not_before = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        not_after = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        revoked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        revocation_reason = 1.337, 
                        alt_names = '', )
                    ],
                total_count = 1.337,
        )
        """

    def testApiV2WorkspaceSlugCertificatesGet200Response(self):
        """Test ApiV2WorkspaceSlugCertificatesGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_approval_requests_get200_response import ApiV1SecretApprovalRequestsGet200Response  # noqa: E501

class TestApiV1SecretApprovalRequestsGet200Response(unittest.TestCase):
    """ApiV1SecretApprovalRequestsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretApprovalRequestsGet200Response:
        """Test ApiV1SecretApprovalRequestsGet200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretApprovalRequestsGet200Response`
        """
        model = ApiV1SecretApprovalRequestsGet200Response()  # noqa: E501
        if include_optional:
            return ApiV1SecretApprovalRequestsGet200Response(
                approvals = [
                    infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner._api_v1_secret_approval_requests_get_200_response_approvals_inner(
                        id = '', 
                        policy_id = '', 
                        has_merged = True, 
                        status = 'open', 
                        conflicts = null, 
                        slug = '', 
                        folder_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_replicated = True, 
                        committer_user_id = '', 
                        status_changed_by_user_id = '', 
                        bypass_reason = '', 
                        policy = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_policy._api_v1_secret_approval_requests_get_200_response_approvals_inner_policy(
                            id = '', 
                            name = '', 
                            approvals = 1.337, 
                            approvers = [
                                ''
                                ], 
                            secret_path = '', 
                            enforcement_level = '', ), 
                        committer_user = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                            user_id = '', 
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            username = '', ), 
                        commits = [
                            infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_commits_inner._api_v1_secret_approval_requests_get_200_response_approvals_inner_commits_inner(
                                op = '', 
                                secret_id = '', )
                            ], 
                        environment = '', 
                        reviewers = [
                            infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_reviewers_inner._api_v1_secret_approval_requests_get_200_response_approvals_inner_reviewers_inner(
                                user_id = '', 
                                status = '', )
                            ], 
                        approvers = [
                            ''
                            ], )
                    ]
            )
        else:
            return ApiV1SecretApprovalRequestsGet200Response(
                approvals = [
                    infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner._api_v1_secret_approval_requests_get_200_response_approvals_inner(
                        id = '', 
                        policy_id = '', 
                        has_merged = True, 
                        status = 'open', 
                        conflicts = null, 
                        slug = '', 
                        folder_id = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_replicated = True, 
                        committer_user_id = '', 
                        status_changed_by_user_id = '', 
                        bypass_reason = '', 
                        policy = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_policy._api_v1_secret_approval_requests_get_200_response_approvals_inner_policy(
                            id = '', 
                            name = '', 
                            approvals = 1.337, 
                            approvers = [
                                ''
                                ], 
                            secret_path = '', 
                            enforcement_level = '', ), 
                        committer_user = infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_committer_user._api_v1_secret_approval_requests_get_200_response_approvals_inner_committerUser(
                            user_id = '', 
                            email = '', 
                            first_name = '', 
                            last_name = '', 
                            username = '', ), 
                        commits = [
                            infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_commits_inner._api_v1_secret_approval_requests_get_200_response_approvals_inner_commits_inner(
                                op = '', 
                                secret_id = '', )
                            ], 
                        environment = '', 
                        reviewers = [
                            infisicalapi_client.models._api_v1_secret_approval_requests_get_200_response_approvals_inner_reviewers_inner._api_v1_secret_approval_requests_get_200_response_approvals_inner_reviewers_inner(
                                user_id = '', 
                                status = '', )
                            ], 
                        approvers = [
                            ''
                            ], )
                    ],
        )
        """

    def testApiV1SecretApprovalRequestsGet200Response(self):
        """Test ApiV1SecretApprovalRequestsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr

class ApiV1PasswordChangePasswordPostRequest(BaseModel):
    """
    ApiV1PasswordChangePasswordPostRequest
    """
    client_proof: StrictStr = Field(default=..., alias="clientProof")
    protected_key: StrictStr = Field(default=..., alias="protectedKey")
    protected_key_iv: StrictStr = Field(default=..., alias="protectedKeyIV")
    protected_key_tag: StrictStr = Field(default=..., alias="protectedKeyTag")
    encrypted_private_key: StrictStr = Field(default=..., alias="encryptedPrivateKey")
    encrypted_private_key_iv: StrictStr = Field(default=..., alias="encryptedPrivateKeyIV")
    encrypted_private_key_tag: StrictStr = Field(default=..., alias="encryptedPrivateKeyTag")
    salt: StrictStr = Field(...)
    verifier: StrictStr = Field(...)
    password: StrictStr = Field(...)
    __properties = ["clientProof", "protectedKey", "protectedKeyIV", "protectedKeyTag", "encryptedPrivateKey", "encryptedPrivateKeyIV", "encryptedPrivateKeyTag", "salt", "verifier", "password"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1PasswordChangePasswordPostRequest:
        """Create an instance of ApiV1PasswordChangePasswordPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1PasswordChangePasswordPostRequest:
        """Create an instance of ApiV1PasswordChangePasswordPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1PasswordChangePasswordPostRequest.parse_obj(obj)

        _obj = ApiV1PasswordChangePasswordPostRequest.parse_obj({
            "client_proof": obj.get("clientProof"),
            "protected_key": obj.get("protectedKey"),
            "protected_key_iv": obj.get("protectedKeyIV"),
            "protected_key_tag": obj.get("protectedKeyTag"),
            "encrypted_private_key": obj.get("encryptedPrivateKey"),
            "encrypted_private_key_iv": obj.get("encryptedPrivateKeyIV"),
            "encrypted_private_key_tag": obj.get("encryptedPrivateKeyTag"),
            "salt": obj.get("salt"),
            "verifier": obj.get("verifier"),
            "password": obj.get("password")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_scim_groups_post200_response import ApiV1ScimGroupsPost200Response  # noqa: E501

class TestApiV1ScimGroupsPost200Response(unittest.TestCase):
    """ApiV1ScimGroupsPost200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1ScimGroupsPost200Response:
        """Test ApiV1ScimGroupsPost200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1ScimGroupsPost200Response`
        """
        model = ApiV1ScimGroupsPost200Response()  # noqa: E501
        if include_optional:
            return ApiV1ScimGroupsPost200Response(
                schemas = [
                    ''
                    ],
                id = '',
                display_name = '',
                members = [
                    infisicalapi_client.models._api_v1_scim_users__org_membership_id__get_201_response_groups_inner._api_v1_scim_Users__orgMembershipId__get_201_response_groups_inner(
                        value = '', 
                        display = '', )
                    ],
                meta = infisicalapi_client.models._api_v1_scim_groups_get_200_response_resources_inner_meta._api_v1_scim_Groups_get_200_response_Resources_inner_meta(
                    resource_type = '', )
            )
        else:
            return ApiV1ScimGroupsPost200Response(
                schemas = [
                    ''
                    ],
                id = '',
                display_name = '',
                meta = infisicalapi_client.models._api_v1_scim_groups_get_200_response_resources_inner_meta._api_v1_scim_Groups_get_200_response_Resources_inner_meta(
                    resource_type = '', ),
        )
        """

    def testApiV1ScimGroupsPost200Response(self):
        """Test ApiV1ScimGroupsPost200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



import os
import json
import base64
import requests
from typing import Dict
from datetime import datetime
import hashlib
import hmac
import urllib.parse


class AWSAuth:
    def __init__(self, client):
        self.client = client

    def aws_iam_auth_login(self, identity_id: str = "") -> Dict:
        if not identity_id:
            identity_id = os.getenv("INFISICAL_AWS_IAM_AUTH_IDENTITY_ID")

        aws_region = self._get_aws_region()
        credentials = self._get_aws_credentials()

        # Prepare request for signing
        iam_request_url = f"https://sts.{aws_region}.amazonaws.com/"
        iam_request_body = "Action=GetCallerIdentity&Version=2011-06-15"

        # Create request
        req = {
            "method": "POST",
            "url": iam_request_url,
            "data": iam_request_body,
            "headers": {}
        }

        # Add date header
        current_time = datetime.utcnow()
        req["headers"]["X-Amz-Date"] = current_time.strftime("%Y%m%dT%H%M%SZ")

        # Calculate payload hash
        payload_hash = hashlib.sha256(iam_request_body.encode()).hexdigest()

        # Sign the request
        self._sign_request(req, credentials, payload_hash, "sts", aws_region, current_time)

        # Prepare headers for the API call
        real_headers = {k: v for k, v in req["headers"].items() if k.lower() != "content-length"}
        real_headers["Host"] = f"sts.{aws_region}.amazonaws.com"
        real_headers["Content-Type"] = "application/x-www-form-urlencoded; charset=utf-8"
        real_headers["Content-Length"] = str(len(iam_request_body))

        # Convert headers to JSON and encode
        json_string_headers = json.dumps(real_headers)
        encoded_headers = base64.b64encode(json_string_headers.encode()).decode()

        # Prepare the request body for the API call
        api_request = {
            "HTTPRequestMethod": req["method"],
            "IamRequestBody": base64.b64encode(iam_request_body.encode()).decode(),
            "IamRequestHeaders": encoded_headers,
            "IdentityId": identity_id
        }

        # Call the API
        credential = self._call_aws_iam_auth_login(api_request)

        # Set the access token
        self.client.set_access_token(credential["accessToken"], "AWS_IAM")


        return credential

    def _get_aws_region(self):
        # Implement AWS region retrieval logic here
        # For this example, we'll use a placeholder
        return "us-west-2"

    def _get_aws_credentials(self):
        # Implement AWS credentials retrieval logic here
        # For this example, we'll use placeholders
        return {
            "AccessKeyId": "YOUR_ACCESS_KEY_ID",
            "SecretAccessKey": "YOUR_SECRET_ACCESS_KEY",
            "SessionToken": "YOUR_SESSION_TOKEN"
        }

    def _sign_request(self, req, credentials, payload_hash, service, region, time):
        # Implement AWS Signature V4 signing process
        # This is a simplified version and may need to be expanded for full functionality
        algorithm = "AWS4-HMAC-SHA256"
        credential_scope = f"{time.strftime('%Y%m%d')}/{region}/{service}/aws4_request"

        string_to_sign = f"{algorithm}\n{req['headers']['X-Amz-Date']}\n{credential_scope}\n"
        string_to_sign += hashlib.sha256(self._canonical_request(req, payload_hash).encode()).hexdigest()

        date_key = hmac.new(f"AWS4{credentials['SecretAccessKey']}".encode(), time.strftime('%Y%m%d').encode(),
                            hashlib.sha256).digest()
        date_region_key = hmac.new(date_key, region.encode(), hashlib.sha256).digest()
        date_region_service_key = hmac.new(date_region_key, service.encode(), hashlib.sha256).digest()
        signing_key = hmac.new(date_region_service_key, b"aws4_request", hashlib.sha256).digest()

        signature = hmac.new(signing_key, string_to_sign.encode(), hashlib.sha256).hexdigest()

        req["headers"]["Authorization"] = (
            f"{algorithm} Credential={credentials['AccessKeyId']}/{credential_scope}, "
            f"SignedHeaders=host;x-amz-date, Signature={signature}"
        )

    def _canonical_request(self, req, payload_hash):
        canonical_headers = "host:" + req["headers"]["Host"] + "\n" + "x-amz-date:" + req["headers"][
            "X-Amz-Date"] + "\n"
        signed_headers = "host;x-amz-date"

        return f"{req['method']}\n/{urllib.parse.urlparse(req['url']).path}\n\n{canonical_headers}\n{signed_headers}\n{payload_hash}"

    def _call_aws_iam_auth_login(self, request):
        response = requests.post(
            f"{self.client.base_url}/v1/auth/aws-auth/login",
            json=request
        )
        response.raise_for_status()
        return response.json()


# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from infisicalapi_client.models.api_v3_secrets_batch_post_request_secrets_inner import ApiV3SecretsBatchPostRequestSecretsInner

class ApiV3SecretsBatchPostRequest(BaseModel):
    """
    ApiV3SecretsBatchPostRequest
    """
    workspace_id: StrictStr = Field(default=..., alias="workspaceId")
    environment: StrictStr = Field(...)
    secret_path: Optional[StrictStr] = Field(default='/', alias="secretPath")
    secrets: conlist(ApiV3SecretsBatchPostRequestSecretsInner, min_items=1) = Field(...)
    __properties = ["workspaceId", "environment", "secretPath", "secrets"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV3SecretsBatchPostRequest:
        """Create an instance of ApiV3SecretsBatchPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in secrets (list)
        _items = []
        if self.secrets:
            for _item in self.secrets:
                if _item:
                    _items.append(_item.to_dict())
            _dict['secrets'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV3SecretsBatchPostRequest:
        """Create an instance of ApiV3SecretsBatchPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV3SecretsBatchPostRequest.parse_obj(obj)

        _obj = ApiV3SecretsBatchPostRequest.parse_obj({
            "workspace_id": obj.get("workspaceId"),
            "environment": obj.get("environment"),
            "secret_path": obj.get("secretPath") if obj.get("secretPath") is not None else '/',
            "secrets": [ApiV3SecretsBatchPostRequestSecretsInner.from_dict(_item) for _item in obj.get("secrets")] if obj.get("secrets") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist, constr, validator

class ApiV1AdditionalPrivilegeUsersTemporaryPostRequest(BaseModel):
    """
    ApiV1AdditionalPrivilegeUsersTemporaryPostRequest
    """
    project_membership_id: constr(strict=True, min_length=1) = Field(default=..., alias="projectMembershipId", description="Project membership id of user")
    slug: Optional[constr(strict=True, max_length=60, min_length=1)] = Field(default=None, description="The slug of the privilege to create.")
    permissions: conlist(StrictStr) = Field(default=..., description="The permission object for the privilege. Refer https://casl.js.org/v6/en/guide/define-rules#the-shape-of-raw-rule to understand the shape")
    temporary_mode: StrictStr = Field(default=..., alias="temporaryMode", description="Type of temporary access given. Types: relative")
    temporary_range: StrictStr = Field(default=..., alias="temporaryRange", description="TTL for the temporay time. Eg: 1m, 1h, 1d")
    temporary_access_start_time: datetime = Field(default=..., alias="temporaryAccessStartTime", description="ISO time for which temporary access should begin.")
    __properties = ["projectMembershipId", "slug", "permissions", "temporaryMode", "temporaryRange", "temporaryAccessStartTime"]

    @validator('temporary_mode')
    def temporary_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('relative'):
            raise ValueError("must be one of enum values ('relative')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiV1AdditionalPrivilegeUsersTemporaryPostRequest:
        """Create an instance of ApiV1AdditionalPrivilegeUsersTemporaryPostRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiV1AdditionalPrivilegeUsersTemporaryPostRequest:
        """Create an instance of ApiV1AdditionalPrivilegeUsersTemporaryPostRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiV1AdditionalPrivilegeUsersTemporaryPostRequest.parse_obj(obj)

        _obj = ApiV1AdditionalPrivilegeUsersTemporaryPostRequest.parse_obj({
            "project_membership_id": obj.get("projectMembershipId"),
            "slug": obj.get("slug"),
            "permissions": obj.get("permissions"),
            "temporary_mode": obj.get("temporaryMode"),
            "temporary_range": obj.get("temporaryRange"),
            "temporary_access_start_time": obj.get("temporaryAccessStartTime")
        })
        return _obj





# coding: utf-8

"""
    Infisical API

    List of all available APIs that can be consumed

    The version of the OpenAPI document: 0.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from infisicalapi_client.models.api_v1_secret_imports_secret_import_id_patch_request import ApiV1SecretImportsSecretImportIdPatchRequest  # noqa: E501

class TestApiV1SecretImportsSecretImportIdPatchRequest(unittest.TestCase):
    """ApiV1SecretImportsSecretImportIdPatchRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiV1SecretImportsSecretImportIdPatchRequest:
        """Test ApiV1SecretImportsSecretImportIdPatchRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiV1SecretImportsSecretImportIdPatchRequest`
        """
        model = ApiV1SecretImportsSecretImportIdPatchRequest()  # noqa: E501
        if include_optional:
            return ApiV1SecretImportsSecretImportIdPatchRequest(
                workspace_id = '',
                environment = '',
                path = '/',
                var_import = infisicalapi_client.models._api_v1_secret_imports__secret_import_id__patch_request_import._api_v1_secret_imports__secretImportId__patch_request_import(
                    environment = '', 
                    path = '', 
                    position = 1.337, )
            )
        else:
            return ApiV1SecretImportsSecretImportIdPatchRequest(
                workspace_id = '',
                environment = '',
                var_import = infisicalapi_client.models._api_v1_secret_imports__secret_import_id__patch_request_import._api_v1_secret_imports__secretImportId__patch_request_import(
                    environment = '', 
                    path = '', 
                    position = 1.337, ),
        )
        """

    def testApiV1SecretImportsSecretImportIdPatchRequest(self):
        """Test ApiV1SecretImportsSecretImportIdPatchRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
